@@ -12,12 +12,14 @@
 #include "../../descriptor/building_desc.h"
 #include "../../descriptor/vehicle_desc.h"
 #include "../../descriptor/goods_desc.h"
+#include "../../descriptor/roadsign_desc.h"
 #include "../../bauer/brueckenbauer.h"
 #include "../../bauer/hausbauer.h"
 #include "../../bauer/tunnelbauer.h"
 #include "../../bauer/vehikelbauer.h"
 #include "../../bauer/goods_manager.h"
 #include "../../bauer/wegbauer.h"
+#include "../../obj/roadsign.h"
 #include "../../simhalt.h"
 #include "../../simware.h"
 #include "../../simworld.h"
@@ -75,6 +77,17 @@ bool building_enables(const building_desc_t* desc, uint8 which)
 	return desc ? desc->get_enabled() & which : 0;
 }
 
+SQInteger building_get_size(HSQUIRRELVM vm)
+{
+	const building_desc_t* desc = param<const building_desc_t*>::get(vm, 1);
+	uint8 rotation = param<uint8>::get(vm, 2);
+	if (desc) {
+		koord size = desc->get_size(rotation);
+		// no automatic coordinate transform please
+		return push_instance(vm, "coord", size.x, size.y);
+	}
+	return -1;
+}
 
 mytime_t get_intro_retire(const obj_desc_timelined_t* desc, bool intro)
 {
@@ -111,21 +124,27 @@ const vector_tpl<const building_desc_t*>& get_available_stations(building_desc_t
 	static vector_tpl<const building_desc_t*> dummy;
 	dummy.clear();
 
-	if (freight == NULL  ||  (type != building_desc_t::depot  &&  type != building_desc_t::generic_stop  &&  type != building_desc_t::generic_extension) ) {
-		return dummy;
+	switch(type) {
+		case building_desc_t::depot:
+		case building_desc_t::generic_stop:
+		case building_desc_t::generic_extension:
+		case building_desc_t::dock:
+		case building_desc_t::flat_dock:
+			break;
+		default:
+			return dummy;
 	}
 
 	const vector_tpl<const building_desc_t*>* p = hausbauer_t::get_list(type);
 
 	// translate freight to enables-flags
-	uint8 enables = haltestelle_t::WARE;
-	switch(freight->get_catg_index()) {
-		case goods_manager_t::INDEX_PAS:  enables = haltestelle_t::PAX;  break;
-		case goods_manager_t::INDEX_MAIL: enables = haltestelle_t::POST; break;
-		default: ;
-	}
-	if (type == building_desc_t::depot) {
-		enables = 0;
+	uint8 enables = 0;
+	if (freight  &&  type != building_desc_t::depot) {
+		switch(freight->get_catg_index()) {
+			case goods_manager_t::INDEX_PAS:  enables = haltestelle_t::PAX;  break;
+			case goods_manager_t::INDEX_MAIL: enables = haltestelle_t::POST; break;
+			default:                          enables = haltestelle_t::WARE;
+		}
 	}
 
 	uint16 time = welt->get_timeline_year_month();
@@ -226,6 +245,11 @@ namespace script_api {
 	}
 };
 
+bool is_traffic_light(const roadsign_desc_t *d)
+{
+	return !d->is_signal_type()  &&  d->is_traffic_light();
+}
+
 
 void export_goods_desc(HSQUIRRELVM vm)
 {
@@ -245,6 +269,10 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 * @return true if this==other
 	 */
 	register_method(vm, &are_equal, "is_equal", true);
+	/**
+	 * @returns if object is still valid.
+	 */
+	export_is_valid<const obj_named_desc_t*>(vm); //register_function("is_valid")
 	end_class(vm);
 
 	/**
@@ -379,8 +407,9 @@ void export_goods_desc(HSQUIRRELVM vm)
 	/**
 	 * @param rotation
 	 * @return size of building in the given @p rotation
+	 * @typemask coord(integer)
 	 */
-	register_method(vm, &building_desc_t::get_size, "get_size");
+	register_function(vm, building_get_size, "get_size", 2,  "x i");
 	/**
 	 * @return monthly maintenance cost
 	 */
@@ -465,7 +494,7 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 * Entries are of type @ref building_desc_x.
 	 * @param type building type from @ref building_desc_x::building_type
 	 * @param wt waytype
-	 * @param freight station should accept this freight
+	 * @param freight station should accept this freight (if null then return all buildings)
 	 * @returns the list
 	 */
 	STATIC register_method(vm, &get_available_stations, "get_available_stations", false, true);
@@ -603,4 +632,50 @@ void export_goods_desc(HSQUIRRELVM vm)
 	 */
 	register_method(vm, &ware_t::calc_revenue, "calc_revenue", true);
 	end_class(vm);
+
+	/**
+	 * Descriptor of roadsigns and signals.
+	 */
+	begin_desc_class(vm, "sign_desc_x", "obj_desc_transport_x", (GETDESCFUNC)param<const roadsign_desc_t*>::getfunc());
+
+	/**
+	 * @returns true if sign is one-way sign
+	 */
+	register_method(vm, &roadsign_desc_t::is_single_way, "is_one_way");
+	/**
+	 * @returns true if sign is private-way sign
+	 */
+	register_method(vm, &roadsign_desc_t::is_private_way, "is_private_way");
+	/**
+	 * @returns true if sign is traffic light
+	 */
+	register_method(vm, &is_traffic_light, "is_traffic_light", true);
+	/**
+	 * @returns true if sign is choose sign
+	 */
+	register_method(vm, &roadsign_desc_t::is_choose_sign, "is_choose_sign");
+	/**
+	 * @returns true if sign is signal
+	 */
+	register_method(vm, &roadsign_desc_t::is_signal, "is_signal");
+	/**
+	 * @returns true if sign is pre signal (distant signal)
+	 */
+	register_method(vm, &roadsign_desc_t::is_pre_signal, "is_pre_signal");
+	/**
+	 * @returns true if sign is long-block signal
+	 */
+	register_method(vm, &roadsign_desc_t::is_longblock_signal, "is_longblock_signal");
+	/**
+	 * @returns true if sign is end-of-choose sign
+	 */
+	register_method(vm, &roadsign_desc_t::is_end_choose_signal, "is_end_choose_signal");
+	/**
+	 * Returns a list with available bridge types.
+	 * @param wt waytype
+	 */
+	STATIC register_method(vm, roadsign_t::get_available_signs, "get_available_signs", false, true);
+
+	end_class(vm);
+
 }
