@@ -854,8 +854,10 @@ void bridge_builder_t::build_bridge(player_t *player, const koord3d start, const
 				grund_t *to = NULL;
 				if(  ribi_t::is_single(ribi)  &&  gr->get_neighbour(to, invalid_wt, ribi_t::backward(ribi))) {
 					// connect to open sea, calc_image will recompute ribi at to.
-					if (to->is_water()) {
+					if (desc->get_waytype() == water_wt  &&  to->is_water()) {
+						gr->weg_erweitern(water_wt, ribi_t::backward(ribi));
 						to->calc_image();
+						continue;
 					}
 					// only single tile under bridge => try to connect to next tile
 					way_builder_t bauigel(player);
