@@ -9,6 +9,7 @@
  * The depot window, where to buy convois
  */
 
+#include <algorithm>
 #include <stdio.h>
 #include <string.h>
 
@@ -71,18 +72,23 @@ static const char* engine_type_names[9] =
 	"battery"
 };
 
+enum { sb_name, sb_capacity, sb_price, sb_cost, sb_cost_per_unit, sb_speed, sb_power, sb_weight, sb_intro_date, sb_retire_date, sb_length };
+static int sort_by_action;
+
 bool depot_frame_t::show_retired_vehicles = false;
 bool depot_frame_t::show_all = true;
 
-
 depot_frame_t::depot_frame_t(depot_t* depot) :
 	gui_frame_t( translator::translate(depot->get_name()), depot->get_owner()),
 	depot(depot),
 	icnv(depot->convoi_count()-1),
 	lb_convoi_line("Serves Line:", SYSCOL_TEXT, gui_label_t::left),
+	lb_sort_by("Sort by:", SYSCOL_TEXT, gui_label_t::right),
+	lb_name_filter_input("Search:", SYSCOL_TEXT, gui_label_t::right),
 	lb_veh_action("Fahrzeuge:", SYSCOL_TEXT, gui_label_t::right),
 	convoi_pics(depot->get_max_convoi_length()),
 	convoi(&convoi_pics),
+	scrolly_convoi(&cont_convoi),
 	pas(&pas_vec),
 	electrics(&electrics_vec),
 	loks(&loks_vec),
@@ -134,7 +140,11 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 	convoi.set_player_nr(depot->get_player_nr());
 	convoi.add_listener(this);
 
-	add_component(&convoi);
+	cont_convoi.add_component(&lb_convoi_number);
+	cont_convoi.add_component(&convoi);
+
+	//	add_component(&convoi);
+
 	add_component(&lb_convoi_count);
 	add_component(&lb_convoi_speed);
 	add_component(&lb_convoi_cost);
@@ -151,15 +161,19 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 	convoi_length_too_slow_sb = 0;
 	convoi_tile_length_sb = 0;
 	new_vehicle_length_sb = 0;
-	if(  depot->get_typ() != depot_t::schiffdepot  &&  depot->get_typ() != depot_t::airdepot  ) { // no convoy length bar for ships or aircraft
+	if(  depot->get_max_convoi_length() > 1  ) { // no convoy length bar for ships or aircraft
 		sb_convoi_length.add_color_value(&convoi_tile_length_sb, color_idx_to_rgb(COL_BROWN));
 		sb_convoi_length.add_color_value(&new_vehicle_length_sb, color_idx_to_rgb(COL_DARK_GREEN));
 		sb_convoi_length.add_color_value(&convoi_length_ok_sb, color_idx_to_rgb(COL_GREEN));
 		sb_convoi_length.add_color_value(&convoi_length_slower_sb, color_idx_to_rgb(COL_ORANGE));
 		sb_convoi_length.add_color_value(&convoi_length_too_slow_sb, color_idx_to_rgb(COL_RED));
-		add_component(&sb_convoi_length);
+		cont_convoi.add_component(&sb_convoi_length);
 	}
 
+	scrolly_convoi.set_scrollbar_mode(scrollbar_t::show_disabled);
+	scrolly_convoi.set_size_corner(false);
+	add_component(&scrolly_convoi);
+
 	/*
 	* [ACTIONS]
 	*/
@@ -205,7 +219,9 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 	add_component(&tabs);
 	add_component(&div_tabbottom);
 	add_component(&lb_veh_action);
+	add_component(&lb_sort_by);
 	add_component(&lb_vehicle_filter);
+	add_component(&lb_name_filter_input);
 
 	veh_action = va_append;
 	bt_veh_action.set_typ(button_t::roundbox);
@@ -229,6 +245,10 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 		add_component(&bt_obsolete);
 	}
 
+	sort_by.set_highlight_color(color_idx_to_rgb(depot->get_owner()->get_player_color1() + 1));
+	sort_by.add_listener(this);
+	add_component(&sort_by);
+
 	vehicle_filter.set_highlight_color(color_idx_to_rgb(depot->get_owner()->get_player_color1() + 1));
 	vehicle_filter.add_listener(this);
 	add_component(&vehicle_filter);
@@ -240,7 +260,11 @@ DBG_DEBUG("depot_frame_t::depot_frame_t()","get_max_convoi_length()=%i",depot->g
 	build_vehicle_lists();
 
 	// text will be translated by ourselves (after update data)!
-	lb_convois.set_text_pointer( txt_convois );
+	lb_convois.set_text_pointer(txt_convois);
+
+	lb_convoi_count.set_text_pointer(txt_convoi_count);
+	lb_convoi_number.set_text_pointer(txt_convoi_number);
+
 	lb_convoi_count.set_text_pointer( txt_convoi_count );
 	lb_convoi_speed.set_text_pointer( txt_convoi_speed );
 	lb_convoi_cost.set_text_pointer( txt_convoi_cost );
@@ -298,8 +322,6 @@ void depot_frame_t::layout(scr_size *size)
 	scr_coord_val grid_dx;
 	scr_coord_val placement_dx;
 
-	scr_size win_size = (size!=NULL)? *size : get_windowsize();
-
 	/*
 	* These parameter are adjusted to resolution.
 	* - Some extra space looks nicer.
@@ -311,6 +333,16 @@ void depot_frame_t::layout(scr_size *size)
 	grid_dx = depot->get_x_grid() * get_base_tile_raster_width() / 64 / 2;
 	placement_dx = depot->get_x_grid() * get_base_tile_raster_width() / 64 / 4;
 
+	// calculate some useful default width first (since everything depends on width)
+	scr_size win_size = (size != NULL) ? *size : get_windowsize();
+	if (win_size.w <= 0) {
+		win_size.w = max(D_DEFAULT_WIDTH,(grid.x - grid_dx)*18);
+		win_size.h = 0;
+	}
+	if (size  &&  size->w == 0) {
+		size->w = D_DEFAULT_WIDTH;
+	}
+
 	/*
 	*	Dialog format:
 	*
@@ -330,7 +362,7 @@ void depot_frame_t::layout(scr_size *size)
 	*
 	*  PREV and NEXT are small buttons - Label is adjusted to total width.
 	*/
-	const scr_coord_val SELECT_HEIGHT = 14;
+	const scr_coord_val SELECT_HEIGHT = D_BUTTON_HEIGHT;
 	const scr_coord_val selector_x = max(max(max(max(max(102, proportional_string_width(translator::translate("no convois")) + 4),
 		proportional_string_width(translator::translate("1 convoi")) + 4),
 		proportional_string_width(translator::translate("%d convois")) + 4),
@@ -338,6 +370,8 @@ void depot_frame_t::layout(scr_size *size)
 		line_button.get_size().w + 2 + proportional_string_width(translator::translate(lb_convoi_line.get_text_pointer())) + 4
 		);
 
+	const scr_coord_val BUTTON_WIDTH_DEPOT = max(D_BUTTON_WIDTH,(win_size.w - D_MARGIN_LEFT - D_MARGIN_RIGHT - 4*D_H_SPACE) / 4);
+
 	/*
 	*	Structure of [CONVOI] is a image_list and an infos:
 	*
@@ -348,8 +382,7 @@ void depot_frame_t::layout(scr_size *size)
 	*/
 	const scr_coord_val CLIST_WIDTH = depot->get_max_convoi_length() * (grid.x - grid_dx) + 2 * gui_image_list_t::BORDER;
 	const scr_coord_val CLIST_HEIGHT = grid.y + 2 * gui_image_list_t::BORDER + 5;
-	const scr_coord_val CINFO_HEIGHT = LINESPACE * 4 + 1;
-	const scr_coord_val CONVOI_WIDTH = CLIST_WIDTH + placement_dx;
+	const scr_coord_val CINFO_HEIGHT = LINESPACE * 3 + D_BUTTON_HEIGHT + 1;
 
 	/*
 	*	Structure of [ACTIONS] is a row of buttons:
@@ -357,28 +390,20 @@ void depot_frame_t::layout(scr_size *size)
 	*	    [Start][Schedule][Destroy][Sell]
 	*	    [new Route][change Route][delete Route]
 	*/
-	const scr_coord_val ACTIONS_WIDTH = D_DEFAULT_WIDTH + 110; // because depot has a text input frame for search
-	const scr_coord_val ACTIONS_HEIGHT = D_BUTTON_HEIGHT;
-
 	/*
 	*	Structure of [VINFO] is one multiline text.
 	*/
-	const scr_coord_val VINFO_HEIGHT =  6*LINESPACE + D_BUTTON_HEIGHT*2 + D_V_SPACE;
-
-	/*
-	* Total width is the max from [CONVOI] and [ACTIONS] width.
-	*/
-	const scr_coord_val MIN_DEPOT_FRAME_WIDTH = max(CONVOI_WIDTH, ACTIONS_WIDTH);
-	const scr_coord_val DEPOT_FRAME_WIDTH = max(win_size.w, max(CONVOI_WIDTH, ACTIONS_WIDTH));
+	const scr_coord_val VINFO_HEIGHT =  7*LINESPACE + D_BUTTON_HEIGHT + D_EDIT_HEIGHT + 5*D_V_SPACE;
 
 	/*
 	*  Now we can do the first vertical adjustment:
+	*  Calculate position of each element to tabs.
 	*/
 	const scr_coord_val SELECT_VSTART = D_MARGIN_TOP;
-	const scr_coord_val CONVOI_VSTART = SELECT_VSTART + SELECT_HEIGHT + LINESPACE;
-	const scr_coord_val CINFO_VSTART = CONVOI_VSTART + CLIST_HEIGHT;
+	const scr_coord_val CONVOI_VSTART = SELECT_VSTART + SELECT_HEIGHT + LINESPACE + D_V_SPACE;
+	const scr_coord_val CINFO_VSTART = CONVOI_VSTART + CLIST_HEIGHT +  D_SCROLLBAR_HEIGHT*(CLIST_WIDTH >= win_size.w-D_MARGIN_LEFT-D_MARGIN_RIGHT);
 	const scr_coord_val ACTIONS_VSTART = CINFO_VSTART + CINFO_HEIGHT;
-	const scr_coord_val PANEL_VSTART = ACTIONS_VSTART + ACTIONS_HEIGHT;
+	const scr_coord_val PANEL_VSTART = ACTIONS_VSTART + D_BUTTON_HEIGHT;
 
 	/*
 	* Now we determine the row/col layout for the panel and the total panel
@@ -387,8 +412,8 @@ void depot_frame_t::layout(scr_size *size)
 	* Total width will be expanded to match complete columns in panel.
 	*/
 	const scr_coord_val total_h = PANEL_VSTART + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + D_TAB_HEADER_HEIGHT + 2 * gui_image_list_t::BORDER + D_MARGIN_BOTTOM + 1;
-	scr_coord_val PANEL_ROWS = max(1, ((win_size.h-total_h)/grid.y) );
-	if(  size  &&  size->h == 0  ) {
+	scr_coord_val PANEL_ROWS = max(1, ((win_size.h - total_h) / grid.y));
+	if (size  &&  size->h == 0) {
 		PANEL_ROWS = 3;
 	}
 	const scr_coord_val PANEL_HEIGHT = PANEL_ROWS * grid.y + D_TAB_HEADER_HEIGHT + 2 * gui_image_list_t::BORDER;
@@ -401,104 +426,122 @@ void depot_frame_t::layout(scr_size *size)
 	const scr_coord_val TOTAL_HEIGHT = PANEL_VSTART + PANEL_HEIGHT + D_V_SPACE + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + 1 + D_MARGIN_BOTTOM;
 	const scr_coord_val MIN_TOTAL_HEIGHT = PANEL_VSTART + MIN_PANEL_HEIGHT + D_V_SPACE + VINFO_HEIGHT + D_TITLEBAR_HEIGHT + 1 + D_MARGIN_BOTTOM;
 
+	// now we know also the height, so we can set the size of the whole dialogue
+	if(  win_size.h <= 0  ) {
+		// set default size on first call
+		win_size.h = TOTAL_HEIGHT;
+	}
+	win_size.h = max(win_size.h, MIN_TOTAL_HEIGHT);
+	if(  size  ) {
+		*size = win_size;
+	}
+	gui_frame_t::set_windowsize(win_size);
+	set_min_windowsize(scr_size(D_DEFAULT_WIDTH, MIN_TOTAL_HEIGHT));
+
 	/*
 	* DONE with layout planning - now build everything.
 	*/
-	set_min_windowsize(scr_size(MIN_DEPOT_FRAME_WIDTH, MIN_TOTAL_HEIGHT));
-	if(  win_size.w < DEPOT_FRAME_WIDTH  ) {
-		gui_frame_t::set_windowsize(scr_size(MIN_DEPOT_FRAME_WIDTH, max(win_size.h,MIN_TOTAL_HEIGHT) ));
-	}
-	if(  size  &&  size->w == 0  ) {
-		size->w = DEPOT_FRAME_WIDTH;
-	}
-	if(  size  &&  size->h == 0  ) {
-		size->h = TOTAL_HEIGHT;
-	}
-
-	second_column_x = D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 2 / 4;
-	const scr_coord_val second_column_w = DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - second_column_x;
 
 	/*
 	 * [SELECT]:
 	 */
 	lb_convois.set_pos(scr_coord(D_MARGIN_LEFT, SELECT_VSTART + 3));
-	lb_convois.set_width( selector_x - D_H_SPACE );
+	lb_convois.set_width(selector_x - D_H_SPACE);
 
 	convoy_selector.set_pos(scr_coord(D_MARGIN_LEFT + selector_x, SELECT_VSTART));
-	convoy_selector.set_size(scr_size(DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, D_BUTTON_HEIGHT));
-	convoy_selector.set_max_size(scr_size(DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, LINESPACE * 13 + 2 + 16));
+	convoy_selector.set_size(scr_size(win_size.w - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, D_BUTTON_HEIGHT));
+	convoy_selector.set_max_size(scr_size(win_size.w - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, LINESPACE * 13 + 2 + 16));
 
 	/*
 	 * [SELECT ROUTE]:
 	 * @author hsiegeln
 	 */
-	line_button.set_pos(scr_coord(D_MARGIN_LEFT, SELECT_VSTART + D_BUTTON_HEIGHT + 3));
-	lb_convoi_line.set_pos(scr_coord(D_MARGIN_LEFT + line_button.get_size().w + 2, SELECT_VSTART + D_BUTTON_HEIGHT + 3));
-	lb_convoi_line.set_width( selector_x - line_button.get_size().w - 2 - D_H_SPACE );
+	line_button.set_pos(scr_coord(D_MARGIN_LEFT, SELECT_VSTART + D_BUTTON_HEIGHT));
+	lb_convoi_line.set_pos(scr_coord(D_MARGIN_LEFT + line_button.get_size().w + 2, SELECT_VSTART + D_BUTTON_HEIGHT));
+	lb_convoi_line.set_width(selector_x - line_button.get_size().w - 2 - D_H_SPACE);
 
 	line_selector.set_pos(scr_coord(D_MARGIN_LEFT + selector_x, SELECT_VSTART + D_BUTTON_HEIGHT));
-	line_selector.set_size(scr_size(DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, D_BUTTON_HEIGHT));
-	line_selector.set_max_size(scr_size(DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, LINESPACE * 13 + 2 + 16));
+	line_selector.set_size(scr_size(win_size.w - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, D_BUTTON_HEIGHT));
+	line_selector.set_max_size(scr_size(win_size.w - D_MARGIN_RIGHT - D_MARGIN_LEFT - selector_x, LINESPACE * 13 + 2 + 16));
+
+	line_button.align_to(&line_selector, ALIGN_CENTER_V);
+	lb_convoi_line.align_to(&line_selector, ALIGN_CENTER_V);
 
 	/*
 	 * [CONVOI]
 	 */
 	convoi.set_grid(scr_coord(grid.x - grid_dx, grid.y));
 	convoi.set_placement(scr_coord(placement.x - placement_dx, placement.y));
-	convoi.set_pos(scr_coord((DEPOT_FRAME_WIDTH-CLIST_WIDTH) / 2, CONVOI_VSTART));
+	convoi.set_pos(scr_coord(0, 0));
 	convoi.set_size(scr_size(CLIST_WIDTH, CLIST_HEIGHT));
 
-	sb_convoi_length.set_pos(scr_coord((DEPOT_FRAME_WIDTH-CLIST_WIDTH) / 2 + 5,CONVOI_VSTART + grid.y + 5));
+	sb_convoi_length.set_pos(scr_coord(5, grid.y + 5));
 	sb_convoi_length.set_size(scr_size(CLIST_WIDTH - 10, 4));
 
+	cont_convoi.set_size(scr_size(CLIST_WIDTH, grid.y + 5 + 4));
+	scrolly_convoi.set_size(scr_size(win_size.w - D_MARGIN_LEFT - D_MARGIN_RIGHT, cont_convoi.get_size().h + (3+D_SCROLLBAR_HEIGHT)*(CLIST_WIDTH >= win_size.w-D_MARGIN_LEFT-D_MARGIN_RIGHT) ));
+	scrolly_convoi.set_show_scroll_x(true);
+	scrolly_convoi.set_show_scroll_y(false);
+	scrolly_convoi.set_scroll_discrete_x(false);
+	scrolly_convoi.set_size_corner(false);
+	scrolly_convoi.set_pos(scr_coord(D_MARGIN_LEFT,CONVOI_VSTART));
+
+	lb_convoi_number.set_width(30);
+	lb_convoi_number.set_color(COL_WHITE);
+
+	// place for description text
+	second_column_x = D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT+D_H_SPACE*2)*2;
+	second_column_w = (BUTTON_WIDTH_DEPOT+D_H_SPACE)*2;
+
 	lb_convoi_count.set_pos(scr_coord(D_MARGIN_LEFT, CINFO_VSTART));
-	lb_convoi_count.set_width( second_column_w - D_H_SPACE );
+	lb_convoi_count.set_width(second_column_w);
+
 	cont_convoi_capacity.set_pos(scr_coord(second_column_x, CINFO_VSTART));
 	cont_convoi_capacity.set_width(second_column_w);
 
 	lb_convoi_cost.set_pos(scr_coord(D_MARGIN_LEFT, CINFO_VSTART + LINESPACE * 1));
-	lb_convoi_cost.set_width( second_column_w - D_H_SPACE );
+	lb_convoi_cost.set_width(second_column_w);
 	lb_convoi_value.set_pos(scr_coord(second_column_x, CINFO_VSTART + LINESPACE * 1));
 	lb_convoi_value.set_width(second_column_w);
 
 	lb_convoi_power.set_pos(scr_coord(D_MARGIN_LEFT, CINFO_VSTART + LINESPACE * 2));
-	lb_convoi_power.set_width( second_column_w - D_H_SPACE );
+	lb_convoi_power.set_width(second_column_w);
 	lb_convoi_weight.set_pos(scr_coord(second_column_x, CINFO_VSTART + LINESPACE * 2));
 	lb_convoi_weight.set_width(second_column_w);
 
 	lb_convoi_speed.set_pos(scr_coord(D_MARGIN_LEFT, CINFO_VSTART + LINESPACE * 3));
-	lb_convoi_speed.set_width( DEPOT_FRAME_WIDTH - D_MARGIN_RIGHT - D_MARGIN_LEFT );
+	lb_convoi_speed.set_width(win_size.w - D_MARGIN_RIGHT - D_MARGIN_LEFT);
 
 	/*
 	 * [ACTIONS]
 	 */
 	bt_start.set_pos(scr_coord(D_MARGIN_LEFT, ACTIONS_VSTART));
-	bt_start.set_size(scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) / 4 - 3, D_BUTTON_HEIGHT));
+	bt_start.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
 	bt_start.set_text("Start");
 
-	bt_schedule.set_pos(scr_coord(D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) / 4 + 1, ACTIONS_VSTART));
-	bt_schedule.set_size(scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 2 / 4 - (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) / 4 - 3, D_BUTTON_HEIGHT));
+	bt_schedule.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT + D_H_SPACE), ACTIONS_VSTART));
+	bt_schedule.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
 	bt_schedule.set_text("Fahrplan");
 
-	bt_copy_convoi.set_pos(scr_coord(D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 2 / 4 + 2, ACTIONS_VSTART));
-	bt_copy_convoi.set_size(scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 - (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 2 / 4 - 3, D_BUTTON_HEIGHT));
+	bt_copy_convoi.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT + D_H_SPACE)*2, ACTIONS_VSTART));
+	bt_copy_convoi.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
 	bt_copy_convoi.set_text("Copy Convoi");
 
-	bt_sell.set_pos(scr_coord(D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 + 3, ACTIONS_VSTART));
-	bt_sell.set_size(scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) - (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 - 3, D_BUTTON_HEIGHT));
+	bt_sell.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT + D_H_SPACE)*3, ACTIONS_VSTART));
+	bt_sell.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
 	bt_sell.set_text("verkaufen");
 
 	/*
 	* [PANEL]
 	*/
 	tabs.set_pos(scr_coord(0, PANEL_VSTART));
-	tabs.set_size(scr_size(DEPOT_FRAME_WIDTH, PANEL_HEIGHT));
+	tabs.set_size(scr_size(win_size.w, PANEL_HEIGHT));
 
 	pas.set_grid(grid);
 	pas.set_placement(placement);
-	pas.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH,0));
+	pas.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH, 0));
 	pas.recalc_size();
-	pas.set_pos(scr_coord(0,0));
+	pas.set_pos(scr_coord(0, 0));
 	cont_pas.set_size(pas.get_size());
 	scrolly_pas.set_size(scrolly_pas.get_size());
 	scrolly_pas.set_scroll_amount_y(grid.y);
@@ -507,9 +550,9 @@ void depot_frame_t::layout(scr_size *size)
 
 	electrics.set_grid(grid);
 	electrics.set_placement(placement);
-	electrics.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH,0));
+	electrics.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH, 0));
 	electrics.recalc_size();
-	electrics.set_pos(scr_coord(0,0));
+	electrics.set_pos(scr_coord(0, 0));
 	cont_electrics.set_size(electrics.get_size());
 	scrolly_electrics.set_size(scrolly_electrics.get_size());
 	scrolly_electrics.set_scroll_amount_y(grid.y);
@@ -518,9 +561,9 @@ void depot_frame_t::layout(scr_size *size)
 
 	loks.set_grid(grid);
 	loks.set_placement(placement);
-	loks.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH,0));
+	loks.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH, 0));
 	loks.recalc_size();
-	loks.set_pos(scr_coord(0,0));
+	loks.set_pos(scr_coord(0, 0));
 	cont_loks.set_size(loks.get_size());
 	scrolly_loks.set_size(scrolly_loks.get_size());
 	scrolly_loks.set_scroll_amount_y(grid.y);
@@ -529,42 +572,52 @@ void depot_frame_t::layout(scr_size *size)
 
 	waggons.set_grid(grid);
 	waggons.set_placement(placement);
-	waggons.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH,0));
+	waggons.set_size(tabs.get_size() - scr_size(D_SCROLLBAR_WIDTH, 0));
 	waggons.recalc_size();
-	waggons.set_pos(scr_coord(0,0));
+	waggons.set_pos(scr_coord(0, 0));
 	cont_waggons.set_size(waggons.get_size());
 	scrolly_waggons.set_size(scrolly_waggons.get_size());
 	scrolly_waggons.set_scroll_amount_y(grid.y);
 	scrolly_waggons.set_scroll_discrete_y(false);
 	scrolly_waggons.set_size_corner(false);
 
-	div_tabbottom.set_pos(scr_coord(0,PANEL_VSTART + PANEL_HEIGHT));
-	div_tabbottom.set_width(DEPOT_FRAME_WIDTH);
+	div_tabbottom.set_pos(scr_coord(0, PANEL_VSTART + PANEL_HEIGHT));
+	div_tabbottom.set_width(win_size.w);
 
 	/*
 	* [BOTTOM]
 	*/
-	bt_veh_action.set_pos(scr_coord(D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 + 3, INFO_VSTART));
-	bt_veh_action.set_size(scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) - (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 - 3, D_BUTTON_HEIGHT));
+	bt_veh_action.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT+D_H_SPACE)*3, INFO_VSTART));
+	bt_veh_action.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
 
-	lb_veh_action.align_to(&bt_veh_action, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_CENTER_V, scr_coord(D_V_SPACE,0));
+	lb_veh_action.align_to(&bt_veh_action, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_CENTER_V, scr_coord(D_H_SPACE, 0));
 
-	bt_show_all.set_pos(scr_coord(D_MARGIN_LEFT, INFO_VSTART + D_BUTTON_HEIGHT + 1));
+	vehicle_filter.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT+D_H_SPACE)*3, INFO_VSTART + D_BUTTON_HEIGHT + D_V_SPACE));
+	vehicle_filter.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
+	vehicle_filter.set_max_size(scr_size(D_BUTTON_WIDTH, LINESPACE*7));
 
-	const int w = max(72, bt_show_all.get_size().w);
-	bt_obsolete.set_pos(scr_coord(D_MARGIN_LEFT + w + 4 + 6, INFO_VSTART + D_BUTTON_HEIGHT + 1));
+	lb_vehicle_filter.align_to(&vehicle_filter, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_TOP, scr_coord(D_H_SPACE,D_GET_CENTER_ALIGN_OFFSET(LINESPACE,D_BUTTON_HEIGHT)));
 
-	vehicle_filter.set_pos( scr_coord(D_MARGIN_LEFT + (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 + 3, INFO_VSTART + D_BUTTON_HEIGHT));
-	vehicle_filter.set_size( scr_size((DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) - (DEPOT_FRAME_WIDTH - D_MARGIN_LEFT - D_MARGIN_RIGHT) * 3 / 4 - 3, D_BUTTON_HEIGHT));
-	vehicle_filter.set_max_size( scr_size( D_BUTTON_WIDTH + 60, ((size &&  size->h>0) ? size->h : gui_frame_t::get_windowsize().h)-INFO_VSTART-D_BUTTON_HEIGHT-D_MARGIN_BOTTOM-D_TITLEBAR_HEIGHT ) );
+	bt_show_all.set_pos(scr_coord(D_MARGIN_LEFT, INFO_VSTART + D_BUTTON_HEIGHT + D_V_SPACE));
+	bt_show_all.align_to(&vehicle_filter, ALIGN_CENTER_V);
 
-	lb_vehicle_filter.align_to(&vehicle_filter, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_TOP, scr_coord(D_V_SPACE,D_GET_CENTER_ALIGN_OFFSET(LINESPACE,D_BUTTON_HEIGHT)));
+	name_filter_input.set_size( scr_size( BUTTON_WIDTH_DEPOT, D_EDIT_HEIGHT ) );
+	name_filter_input.set_pos( vehicle_filter.get_pos()+scr_coord(0,D_V_SPACE+D_BUTTON_HEIGHT) );
+	lb_name_filter_input.align_to(&name_filter_input, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_TOP, scr_coord(D_H_SPACE,D_GET_CENTER_ALIGN_OFFSET(LINESPACE,D_BUTTON_HEIGHT)));
 
-	name_filter_input.set_size( vehicle_filter.get_size() );
-	name_filter_input.set_pos( vehicle_filter.get_pos()+scr_coord(0,2+D_BUTTON_HEIGHT));
+	bt_obsolete.set_pos(scr_coord(D_MARGIN_LEFT, INFO_VSTART + (D_BUTTON_HEIGHT + D_V_SPACE)*2));
+	bt_obsolete.align_to(&name_filter_input, ALIGN_CENTER_V);
+
+	int y = name_filter_input.get_pos().y + name_filter_input.get_size().h + D_V_SPACE;
+
+	sort_by.set_pos(scr_coord(D_MARGIN_LEFT + (BUTTON_WIDTH_DEPOT+D_H_SPACE)*3, y));
+	sort_by.set_size(scr_size(BUTTON_WIDTH_DEPOT, D_BUTTON_HEIGHT));
+	sort_by.set_max_size(scr_size(D_BUTTON_WIDTH, LINESPACE * 7));
+	lb_sort_by.align_to(&sort_by, ALIGN_RIGHT | ALIGN_EXTERIOR_H | ALIGN_TOP, scr_coord(D_H_SPACE,D_GET_CENTER_ALIGN_OFFSET(LINESPACE,D_BUTTON_HEIGHT)));
 
 	const scr_coord_val margin = 4;
 	img_bolt.set_pos(scr_coord(get_windowsize().w - skinverwaltung_t::electricity->get_image(0)->get_pic()->w - margin, margin));
+
 }
 
 
@@ -644,7 +697,7 @@ void depot_frame_t::add_to_vehicle_list(const vehicle_desc_t *info)
 		electrics_vec.append(img_data);
 	}
 	// since they come "pre-sorted" for the vehikelbauer, we have to do nothing to keep them sorted
-	else if(info->get_freight_type()==goods_manager_t::passengers  ||  info->get_freight_type()==goods_manager_t::mail) {
+	else if(info->get_freight_type() == goods_manager_t::passengers  ||  info->get_freight_type() == goods_manager_t::mail) {
 		pas_vec.append(img_data);
 	}
 	else if(info->get_power() > 0  ||  info->get_capacity()==0) {
@@ -657,6 +710,89 @@ void depot_frame_t::add_to_vehicle_list(const vehicle_desc_t *info)
 	vehicle_map.set(info, img_data);
 }
 
+// for sort vehicle in the list
+static int compare_freight(const vehicle_desc_t* a, const vehicle_desc_t* b)
+{
+	int cmp = a->get_freight_type()->get_catg() - b->get_freight_type()->get_catg();
+	if (cmp != 0) return cmp;
+	if (a->get_freight_type()->get_catg() == 0) cmp = a->get_freight_type()->get_index() - b->get_freight_type()->get_index();
+	return cmp;
+}
+static int compare_capacity(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_capacity() - b->get_capacity();}
+static int compare_engine(const vehicle_desc_t* a, const vehicle_desc_t* b)
+{
+	return (a->get_capacity() + a->get_power() == 0 ? (uint8)vehicle_desc_t::steam : a->get_engine_type()) - (b->get_capacity() + b->get_power() == 0 ? (uint8)vehicle_desc_t::steam : b->get_engine_type());
+}
+static int compare_price(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_price() - b->get_price();}
+static int compare_cost(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_running_cost() - b->get_running_cost();}
+static int compare_cost_per_unit(const vehicle_desc_t* a, const vehicle_desc_t* b)
+{
+	return a->get_running_cost()*b->get_capacity() - b->get_running_cost()*a->get_capacity();
+}
+static int compare_topspeed(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_topspeed() - b->get_topspeed();}
+static int compare_power(const vehicle_desc_t* a, const vehicle_desc_t* b)	{return (a->get_power() == 0 ? 0x7FFFFFF : a->get_power()) - (b->get_power() == 0 ? 0x7FFFFFF : b->get_power());}
+static int compare_weight(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_weight() - b->get_weight();}
+static int compare_intro_year_month(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_intro_year_month() - b->get_intro_year_month();}
+static int compare_retire_year_month(const vehicle_desc_t* a, const vehicle_desc_t* b) {return a->get_retire_year_month() - b->get_retire_year_month();}
+
+static bool compare_vehicles(const vehicle_desc_t* a, const vehicle_desc_t* b)
+{
+	int cmp = compare_freight(a, b);
+	if (cmp != 0) return cmp < 0;
+	switch (sort_by_action) {
+		case sb_name:
+			cmp = strcmp(translator::translate(a->get_name()), translator::translate(b->get_name()));
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_price:
+			cmp = compare_price(a, b);
+			if (cmp != 0) return cmp < 0;
+		case sb_cost:
+			cmp = compare_cost(a, b);
+			if (cmp != 0) return cmp < 0;
+			cmp = compare_price(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_cost_per_unit:
+			cmp = compare_cost_per_unit(a,b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_speed:
+			cmp = compare_topspeed(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_weight:
+			cmp = compare_weight(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_power:
+			cmp = compare_power(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+		case sb_intro_date:
+			cmp = compare_intro_year_month(a, b);
+			if (cmp != 0) return cmp < 0;
+		case sb_retire_date:
+			cmp = compare_retire_year_month(a, b);
+			if (cmp != 0) return cmp < 0;
+			cmp = compare_intro_year_month(a, b);
+			if (cmp != 0) return cmp < 0;
+			break;
+	}
+	// sort by capacity
+	cmp = compare_capacity(a, b);
+	if (cmp != 0) return cmp < 0;
+	cmp = compare_engine(a, b);
+	if (cmp != 0) return cmp < 0;
+	cmp = compare_topspeed(a, b);
+	if (cmp != 0) return cmp < 0;
+	cmp = compare_power(a, b);
+	if (cmp != 0) return cmp < 0;
+	cmp = compare_intro_year_month(a, b);
+	if (cmp != 0) return cmp < 0;
+	cmp = strcmp(translator::translate(a->get_name()), translator::translate(b->get_name()));
+	return cmp < 0;
+}
 
 // add all current vehicles
 void depot_frame_t::build_vehicle_lists()
@@ -686,18 +822,33 @@ void depot_frame_t::build_vehicle_lists()
 
 	img_bolt.set_image( weg_electrified ? skinverwaltung_t::electricity->get_image_id(0) : IMG_EMPTY );
 
+	vector_tpl<const vehicle_desc_t*> typ_list;
+	if(!show_all  &&  veh_action==va_sell) {
+		FOR(slist_tpl<vehicle_t*>, const v, depot->get_vehicle_list()) {
+			vehicle_desc_t const* const d = v->get_desc();
+			typ_list.append(d);
+		}
+	}
+	else {
+		slist_tpl<const vehicle_desc_t*> const& tmp_list = depot->get_vehicle_type();
+		for(slist_tpl<const vehicle_desc_t*>::const_iterator itr = tmp_list.begin(); itr != tmp_list.end(); ++itr) {
+			typ_list.append(*itr);
+		}
+	}
+	sort_by_action = depot->selected_sort_by;
+	std::sort(typ_list.begin(), typ_list.end(), compare_vehicles);
+
 	// use this to show only sellable vehicles
 	if(!show_all  &&  veh_action==va_sell) {
 		// just list the one to sell
-		FOR(slist_tpl<vehicle_t*>, const v, depot->get_vehicle_list()) {
-			vehicle_desc_t const* const d = v->get_desc();
-			if (vehicle_map.get(d)) continue;
-			add_to_vehicle_list(d);
+		FOR(vector_tpl<vehicle_desc_t const*>, const info, typ_list) {
+			if (vehicle_map.get(info)) continue;
+			add_to_vehicle_list(info);
 		}
 	}
 	else {
 		// list only matching ones
-		FOR(slist_tpl<vehicle_desc_t const*>, const info, depot->get_vehicle_type()) {
+		FOR(vector_tpl<vehicle_desc_t const*>, const info, typ_list) {
 			const vehicle_desc_t *veh = NULL;
 			convoihandle_t cnv = depot->get_convoi(icnv);
 			if(cnv.is_bound() && cnv->get_vehicle_count()>0) {
@@ -741,6 +892,7 @@ static void get_line_list(const depot_t* depot, vector_tpl<linehandle_t>* lines)
 void depot_frame_t::update_data()
 {
 	static const char *txt_veh_action[3] = { "anhaengen", "voranstellen", "verkaufen" };
+	static const char *txt_sort_by[sb_length] = { "Vehicle Name", "Capacity", "Price", "Cost", "Cost per unit", "Max. speed", "Vehicle Power", "Weight", "Intro. date", "Retire date" };
 
 	// change green into blue for retired vehicles
 	const int month_now = welt->get_timeline_year_month();
@@ -959,6 +1111,16 @@ void depot_frame_t::update_data()
 	}
 	vehicle_filter.set_selection(depot->selected_filter);
 
+	sort_by.clear_elements();
+	for(int i = 0; i < sb_length; i++)
+	{
+		sort_by.append_element(new gui_scrolled_list_t::const_text_scrollitem_t(translator::translate(txt_sort_by[i]), SYSCOL_TEXT));
+	}
+	if(  depot->selected_sort_by > sort_by.count_elements()  ) {
+		depot->selected_sort_by = sb_name;
+	}
+	sort_by.set_selection(depot->selected_sort_by);
+
 	// finally: update text
 	uint32 total_pax = 0;
 	uint32 total_mail = 0;
@@ -1055,7 +1217,11 @@ void depot_frame_t::update_data()
 			convoi_tile_length_sb = convoi_length + (cnv->get_tile_length() * CARUNITS_PER_TILE - cnv->get_length());
 
 			txt_convoi_count.clear();
-			txt_convoi_count.printf("%s %i",translator::translate("Station tiles:"), cnv->get_tile_length() );
+			if(  cnv->get_vehicle_count()>1  ) {
+				txt_convoi_count.printf( translator::translate("%i car(s),"), cnv->get_vehicle_count() );
+			}
+			txt_convoi_count.append( translator::translate("Station tiles:") );
+			txt_convoi_count.append( (double)cnv->get_tile_length(), 0 );
 
 			txt_convoi_speed.clear();
 			if(  empty_kmh != (use_sel_weight ? sel_kmh : min_kmh)  ) {
@@ -1119,7 +1285,7 @@ void depot_frame_t::update_data()
 		}
 		else {
 			txt_convoi_count.clear();
-			txt_convoi_count.append( translator::translate("keine Fahrzeuge") );
+			txt_convoi_count.append(translator::translate("keine Fahrzeuge"));
 			txt_convoi_value.clear();
 			txt_convoi_cost.clear();
 			txt_convoi_power.clear();
@@ -1281,9 +1447,12 @@ bool depot_frame_t::action_triggered( gui_action_creator_t *comp, value_t p)
 				veh_action = va_append;
 			}
 			else {
-				veh_action = veh_action + 1;
+				veh_action++;
 			}
 		}
+		else if(  comp == &sort_by  ) {
+			depot->selected_sort_by = sort_by.get_selection();
+		}
 		else if(  comp == &bt_copy_convoi  ) {
 			if(  cnv.is_bound()  ) {
 				if(  !welt->use_timeline()  ||  welt->get_settings().get_allow_buying_obsolete_vehicles()  ||  depot->check_obsolete_inventory( cnv )  ) {
@@ -1534,7 +1703,8 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 	double resale_value = -1.0;
 	const vehicle_desc_t *veh_type = NULL;
 	bool new_vehicle_length_sb_force_zero = false;
-	scr_coord relpos = scr_coord( 0, ((gui_scrollpane_t *)tabs.get_aktives_tab())->get_scroll_y() );
+	sint16 convoi_number = -1;
+	scr_coord relpos = scr_coord(0, ((gui_scrollpane_t *)tabs.get_aktives_tab())->get_scroll_y());
 	int sel_index = lst->index_at( pos + tabs.get_pos() - relpos, x, y - D_TITLEBAR_HEIGHT - D_TAB_HEADER_HEIGHT);
 
 	if(  (sel_index != -1)  &&  (tabs.getroffen(x - pos.x, y - pos.y - D_TITLEBAR_HEIGHT))  ) {
@@ -1551,7 +1721,9 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 	}
 	else {
 		// cursor over a vehicle in the convoi
-		sel_index = convoi.index_at( pos , x, y - D_TITLEBAR_HEIGHT);
+		relpos = scr_coord(scrolly_convoi.get_scroll_x(), 0);
+
+		convoi_number = sel_index = convoi.index_at(pos - relpos + scrolly_convoi.get_pos(), x, y - D_TITLEBAR_HEIGHT);
 		if(  sel_index != -1  ) {
 			convoihandle_t cnv = depot->get_convoi( icnv );
 			veh_type = cnv->get_vehikel( sel_index )->get_desc();
@@ -1625,7 +1797,9 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 		buf.printf( "%s %4.1ft\n", translator::translate("Weight:"), veh_type->get_weight() / 1000.0 );
 		buf.printf( "%s %3d km/h", translator::translate("Max. speed:"), veh_type->get_topspeed() );
 
-		display_multiline_text_rgb( pos.x + D_MARGIN_LEFT, pos.y + D_TITLEBAR_HEIGHT + bt_show_all.get_pos().y + bt_show_all.get_size().h + D_V_SPACE + D_BUTTON_HEIGHT*2 - LINESPACE*2, buf, SYSCOL_TEXT);
+		int yyy = pos.y + D_TITLEBAR_HEIGHT + sort_by.get_pos().y + sort_by.get_size().h
+		          - LINESPACE;
+		display_multiline_text_rgb( pos.x + D_MARGIN_LEFT, yyy, buf, SYSCOL_TEXT);
 
 		// column 2
 		buf.clear();
@@ -1664,12 +1838,19 @@ void depot_frame_t::draw_vehicle_info_text(scr_coord pos)
 			buf.printf( "%s %8s", translator::translate("Restwert:"), tmp );
 		}
 
-		display_multiline_text_rgb( pos.x + second_column_x, pos.y + D_TITLEBAR_HEIGHT + bt_show_all.get_pos().y + bt_show_all.get_size().h + D_V_SPACE + D_BUTTON_HEIGHT*2 - LINESPACE, buf, SYSCOL_TEXT);
+		display_multiline_text_rgb( pos.x + second_column_x, yyy + LINESPACE, buf, SYSCOL_TEXT);
 
 		// update speedbar
 		new_vehicle_length_sb = new_vehicle_length_sb_force_zero ? 0 : convoi_length_ok_sb + convoi_length_slower_sb + convoi_length_too_slow_sb + veh_type->get_length();
+
+		txt_convoi_number.clear();
+		if (convoi_number>-1){
+			txt_convoi_number.printf("%d", convoi_number + 1);
+			lb_convoi_number.set_pos(scr_coord(((depot->get_x_grid() * get_base_tile_raster_width() / 64 + 4) - (depot->get_x_grid() * get_base_tile_raster_width() / 64 / 2))*convoi_number + 4, 4));
+		}
 	}
 	else {
+		txt_convoi_number.clear();
 		new_vehicle_length_sb = 0;
 	}
 
