@@ -93,6 +93,9 @@ private:
 	button_t line_button;	// goto line ...
 
 	gui_label_t lb_convoi_count;
+
+	gui_label_t lb_convoi_number;
+
 	gui_label_t lb_convoi_speed;
 	gui_label_t lb_convoi_cost;
 	gui_label_t lb_convoi_value;
@@ -113,6 +116,10 @@ private:
 	button_t bt_obsolete;
 	button_t bt_show_all;
 
+	gui_label_t lb_sort_by;
+	gui_combobox_t sort_by;
+
+	gui_label_t lb_name_filter_input;
 	static char name_filter_value[64];
 	gui_textinput_t name_filter_input;
 
@@ -134,6 +141,9 @@ private:
 	vector_tpl<gui_image_list_t::image_data_t*> convoi_pics;
 	gui_image_list_t convoi;
 
+	gui_scrollpane_t scrolly_convoi;
+	gui_container_t cont_convoi;
+
 	/// image list of passenger cars
 	vector_tpl<gui_image_list_t::image_data_t*> pas_vec;
 	/// image list of electrified passenger carrier units
@@ -181,6 +191,7 @@ private:
 	cbuffer_t txt_convois;
 
 	cbuffer_t txt_convoi_count;
+	cbuffer_t txt_convoi_number;
 	cbuffer_t txt_convoi_value;
 	cbuffer_t txt_convoi_speed;
 	cbuffer_t txt_convoi_cost;
@@ -188,6 +199,7 @@ private:
 	cbuffer_t txt_convoi_weight;
 
 	scr_coord_val second_column_x; // x position of the second text column
+	scr_coord_val second_column_w;
 
 	enum { va_append, va_insert, va_sell };
 	uint8 veh_action;
