@@ -27,6 +27,7 @@
 #include "../utils/simstring.h"
 
 #include "themeselector.h"
+#include "loadfont_frame.h"
 #include "simwin.h"
 
 // Local params
@@ -53,6 +54,13 @@ gui_frame_t( translator::translate("Helligk. u. Farben") )
 	buttons[23].set_width( L_DIALOG_WIDTH - D_MARGINS_X );
 	cursor.y += D_BUTTON_HEIGHT + D_V_SPACE;
 
+	// CHange font
+	buttons[25].set_pos( cursor );
+	buttons[25].set_typ(button_t::roundbox_state);
+	buttons[25].set_text("Select display font");
+	buttons[25].set_width( L_DIALOG_WIDTH - D_MARGINS_X );
+	cursor.y += D_BUTTON_HEIGHT + D_V_SPACE;
+
 	// Show grid checkbox
 	buttons[17].set_pos( cursor );
 	buttons[17].set_typ(button_t::square_state);
@@ -327,6 +335,7 @@ gui_frame_t( translator::translate("Helligk. u. Farben") )
 
 	// add buttons for sensible keyboard tab order
 	add_component( buttons+23 );
+	add_component( buttons+25 );
 	add_component( buttons+17 );
 	add_component( buttons+16 );
 	add_component( &inp_underground_level );
@@ -374,12 +383,12 @@ gui_frame_t( translator::translate("Helligk. u. Farben") )
 void color_gui_t::set_windowsize(scr_size size)
 {
 	scr_coord_val column;
-	scr_coord_val delta_w = size.w - D_MARGINS_X;
+	scr_coord_val delta_w = size.w - get_windowsize().w;
 
 	for(  int i=0;  i<COLORS_MAX_BUTTONS;  i++  ) {
 		if(  buttons[i].get_type() == button_t::square_state  ) {
 			// resize buttons too to fix text
-			buttons[i].set_size( scr_size(delta_w,buttons[i].get_size().h) );
+			buttons[i].set_width( buttons[i].get_size().w + delta_w );
 		}
 	}
 
@@ -594,6 +603,9 @@ bool color_gui_t::action_triggered( gui_action_creator_t *komp, value_t v)
 		env_t::simple_drawing = !env_t::simple_drawing;
 		buttons[24].pressed = env_t::simple_drawing;
 	}
+	if((buttons+25)==komp) {
+		create_win(new loadfont_frame_t(), w_info, magic_font);
+	}
 	welt->set_dirty();
 	return true;
 }
