@@ -234,7 +234,7 @@ bool factory_builder_t::successfully_loaded()
 			find_producer( producer, current->get_supplier(j)->get_input_type(), 0 );
 			if(  producer.is_contained(current)  ) {
 				// must not happen else
-				dbg->fatal( "factory_builder_t::build_link()", "Factory %s output %s cannot be its own input!", i.key, current->get_supplier(j)->get_input_type()->get_name() );
+				dbg->fatal( "factory_builder_t::successfully_loaded()", "Factory %s output %s cannot be its own input!", i.key, current->get_supplier(j)->get_input_type()->get_name() );
 			}
 		}
 		checksum_t *chk = new checksum_t();
@@ -549,7 +549,7 @@ bool factory_builder_t::can_factory_tree_rotate( const factory_desc_t *desc )
  * is the maximum number of good types for which suppliers chains are built
  * (meaning there are no unfinished factory chains).
  */
-int factory_builder_t::build_link(koord3d* parent, const factory_desc_t* info, sint32 initial_prod_base, int rotate, koord3d* pos, player_t* player, int number_of_chains )
+int factory_builder_t::build_link(koord3d* parent, const factory_desc_t* info, sint32 initial_prod_base, int rotate, koord3d* pos, player_t* player, int number_of_chains, bool ignore_climates)
 {
 	int n = 1;
 	int org_rotation = -1;
@@ -582,6 +582,8 @@ int factory_builder_t::build_link(koord3d* parent, const factory_desc_t* info, s
 		// build consumer (factory) in town
 		stadt_t *city = welt->find_nearest_city(pos->get_2d());
 
+		climate_bits cl = ignore_climates ? ALL_CLIMATES : info->get_building()->get_allowed_climate_bits();
+
 		/* Three variants:
 		 * A:
 		 * A building site, preferably close to the town hall with a street next to it.
@@ -591,12 +593,12 @@ int factory_builder_t::build_link(koord3d* parent, const factory_desc_t* info, s
 		 */
 		bool is_rotate=info->get_building()->get_all_layouts()>1  &&  size.x!=size.y  &&  info->get_building()->can_rotate();
 		// first try with standard orientation
-		koord k = factory_place_with_road_finder(welt).find_place(city->get_pos(), size.x, size.y, info->get_building()->get_allowed_climate_bits());
+		koord k = factory_place_with_road_finder(welt).find_place(city->get_pos(), size.x, size.y, cl);
 
 		// second try: rotated
 		koord k1 = koord::invalid;
 		if (is_rotate  &&  (k == koord::invalid  ||  simrand(256)<128)) {
-			k1 = factory_place_with_road_finder(welt).find_place(city->get_pos(), size.y, size.x, info->get_building()->get_allowed_climate_bits());
+			k1 = factory_place_with_road_finder(welt).find_place(city->get_pos(), size.y, size.x, cl);
 		}
 
 		rotate = simrand( info->get_building()->get_all_layouts() );
@@ -687,7 +689,7 @@ int factory_builder_t::build_chain_link(const fabrik_t* our_fab, const factory_d
 	const int producer_count=count_producers( ware, welt->get_timeline_year_month() );
 
 	if(producer_count==0) {
-		dbg->error("factory_builder_t::build_link()","No producer for %s found, chain incomplete!",ware->get_name() );
+		dbg->error("factory_builder_t::build_chain_link()","No producer for %s found, chain incomplete!",ware->get_name() );
 		return 0;
 	}
 
@@ -701,7 +703,7 @@ int factory_builder_t::build_chain_link(const fabrik_t* our_fab, const factory_d
 	int lcount = supplier->get_supplier_count();
 	int lfound = 0;	// number of found producers
 
-DBG_MESSAGE("factory_builder_t::build_link","supplier_count %i, lcount %i (need %i of %s)",info->get_supplier_count(),lcount,consumption,ware->get_name());
+	DBG_MESSAGE("factory_builder_t::build_chain_link","supplier_count %i, lcount %i (need %i of %s)",info->get_supplier_count(),lcount,consumption,ware->get_name());
 
 	// Hajo: search if there already is one or two (cross-connect everything if possible)
 	FOR(slist_tpl<fabrik_t*>, const fab, welt->get_fab_list()) {
@@ -742,7 +744,7 @@ DBG_MESSAGE("factory_builder_t::build_link","supplier_count %i, lcount %i (need
 							if(production_left>0) {
 								consumption -= production_left;
 								fab->add_lieferziel(our_fab->get_pos().get_2d());
-								DBG_MESSAGE("factory_builder_t::build_link","supplier %s can supply approx %i of %s to us", fd->get_name(), production_left, ware->get_name());
+								DBG_MESSAGE("factory_builder_t::build_chain_link","supplier %s can supply approx %i of %s to us", fd->get_name(), production_left, ware->get_name());
 							}
 							else {
 								/* we steal something; however the total capacity
@@ -779,12 +781,12 @@ DBG_MESSAGE("factory_builder_t::build_link","supplier_count %i, lcount %i (need
 	if(  producer.empty()  ) {
 		// can happen with timeline
 		if(!info->is_consumer_only()) {
-			dbg->error( "factory_builder_t::build_link()", "no producer for %s!", ware->get_name() );
+			dbg->error( "factory_builder_t::build_chain_link()", "no producer for %s!", ware->get_name() );
 			return 0;
 		}
 		else {
 			// only consumer: Will do with partly covered chains
-			dbg->error( "factory_builder_t::build_link()", "no producer for %s!", ware->get_name() );
+			dbg->error( "factory_builder_t::build_chain_link()", "no producer for %s!", ware->get_name() );
 		}
 	}
 
@@ -817,8 +819,8 @@ DBG_MESSAGE("factory_builder_t::build_link","supplier_count %i, lcount %i (need
 
 		INT_CHECK("fabrikbauer 697");
 
-DBG_MESSAGE("factory_builder_t::build_link","Try to built supplier %s at (%i,%i) r=%i for %s.",producer_d->get_name(),k.x,k.y,rotate,info->get_name());
-		n += build_link(&parent_pos, producer_d, -1 /*random prodbase */, rotate, &k, player, 10000 );
+		DBG_MESSAGE("factory_builder_t::build_chain_link","Try to built supplier %s at (%i,%i) r=%i for %s.",producer_d->get_name(),k.x,k.y,rotate,info->get_name());
+		n += build_link(&parent_pos, producer_d, -1 /*random prodbase */, rotate, &k, player, 10000, ignore_climates);
 		lfound ++;
 
 		INT_CHECK( "fabrikbauer 702" );
@@ -826,7 +828,7 @@ DBG_MESSAGE("factory_builder_t::build_link","Try to built supplier %s at (%i,%i)
 		// now subtract current supplier
 		fabrik_t *fab = fabrik_t::get_fab(k.get_2d() );
 		if(fab==NULL) {
-DBG_MESSAGE( "factory_builder_t::build_link", "Failed to build at %s", k.get_str() );
+			DBG_MESSAGE( "factory_builder_t::build_chain_link", "Failed to build at %s", k.get_str() );
 			retry --;
 			continue;
 		}
@@ -839,7 +841,7 @@ DBG_MESSAGE( "factory_builder_t::build_link", "Failed to build at %s", k.get_str
 				sint32 production = fab->get_base_production() * fd->get_product(gg)->get_factor();
 				// the take care of how much this factory could supply
 				consumption -= production;
-				DBG_MESSAGE("factory_builder_t::build_link", "new supplier %s can supply approx %i of %s to us", fd->get_name(), production, ware->get_name());
+				DBG_MESSAGE("factory_builder_t::build_chain_link", "new supplier %s can supply approx %i of %s to us", fd->get_name(), production, ware->get_name());
 				break;
 			}
 		}
@@ -1002,7 +1004,7 @@ next_ware_check:
 				}
 				if(welt->lookup(pos)) {
 					// Space found...
-					nr += build_link(NULL, fab, -1 /* random prodbase */, rotation, &pos, welt->get_public_player(), 1 );
+					nr += build_link(NULL, fab, -1 /* random prodbase */, rotation, &pos, welt->get_public_player(), 1, ignore_climates);
 					if(nr>0) {
 						fabrik_t *our_fab = fabrik_t::get_fab( pos.get_2d() );
 						reliefkarte_t::get_karte()->calc_map_size();
