@@ -172,14 +172,6 @@ void grund_t::operator delete(void* p, size_t s)
 }
 
 
-grund_t::grund_t(loadsave_t *file)
-{
-	flags = 0;
-	back_imageid = 0;
-	rdwr(file);
-}
-
-
 void grund_t::rdwr(loadsave_t *file)
 {
 	koord k = pos.get_2d();
@@ -635,20 +627,10 @@ void grund_t::info(cbuffer_t& buf) const
 	if(get_weg_ribi_unmasked(water_wt)) {
 		buf.printf("\nwater ribi: %i",get_weg_ribi_unmasked(water_wt));
 	}
-	buf.printf("\ndraw_as_obj= %i",(flags&draw_as_obj)!=0);
-	buf.append("\nclimates= ");
-
-	bool following = false;
-	climate cl = welt->get_climate( get_pos().get_2d() );
-	for(  uint16 i=0;  i < MAX_CLIMATES;  i++  ) {
-		if(  cl & (1<<i)  ) {
-			if(  following  ) {
-				buf.append( ", " );
-			}
-			following = true;
-			buf.append( translator::translate( ground_desc_t::get_climate_name_from_bit((climate)i) ) );
-		}
+	if(is_water()) {
+		buf.printf("\ncanal ribi: %i", ((const wasser_t*)this)->get_canal_ribi());
 	}
+	buf.printf("\ndraw_as_obj= %i",(flags&draw_as_obj)!=0);
 #endif
 }
 
@@ -880,6 +862,12 @@ void grund_t::calc_back_image(const sint8 hgt, const slope_t::type slope_this)
 			if(  const grund_t *gr=welt->lookup_kartenboden(k + testdir[i] - koord(step,step))  ) {
 				sint16 h = gr->get_disp_height()*scale_z_step;
 				sint8 s = gr->get_disp_slope();
+				// tile should hide anything in tunnel portal behind (tile not in direction of tunnel)
+				if (step == 0  &&  ((i&1)==0)  &&  s  &&  gr->ist_tunnel()) {
+					if ( ribi_t::reverse_single(ribi_type(s)) != ribi_type(testdir[i])) {
+						s = slope_t::flat;
+					}
+				}
 				// take backimage into account, take base-height of back image as corner heights
 				sint8 bb = abs(gr->back_imageid);
 				sint8 lh = 2, rh = 2; // height of start of back image
@@ -1162,7 +1150,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 				}
 				if(  way_ribi & ribi_t::north  ) {
 					const int dh = corner_nw(get_disp_way_slope()) * hgt_step;
-					add_poly_clip( xpos + raster_tile_width - 1, ypos + 3 * raster_tile_width / 4 - 1 - dh, xpos + raster_tile_width / 2 + 1, ypos + raster_tile_width / 2 - dh, ribi_t::north | non_convex CLIP_NUM_PAR );
+					add_poly_clip( xpos + raster_tile_width, ypos + 3 * raster_tile_width / 4 - dh, xpos + raster_tile_width / 2, ypos + raster_tile_width / 2 - dh, ribi_t::north | non_convex CLIP_NUM_PAR );
 				}
 				activate_ribi_clip( (way_ribi & ribi_t::northwest) | non_convex  CLIP_NUM_PAR );
 			}
@@ -1404,7 +1392,7 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 		ribi = (static_cast<const wasser_t*>(this))->get_weg_ribi(water_wt);
 	}
 
-	// now ways? - no clipping needed, avoid all the ribi-checks
+	// no ways? - no clipping needed, avoid all the ribi-checks
 	if (ribi==ribi_t::none) {
 		// display background
 		const uint8 offset_vh = display_obj_bg( xpos, ypos, is_global, true, visible CLIP_NUM_PAR );
@@ -1419,9 +1407,14 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 
 	// ships might be large and could be clipped by vertical walls on our tile
 	const bool ontile_se = back_imageid  &&  is_water();
-
 	// get slope of way as displayed
 	const uint8 slope = get_disp_way_slope();
+	// tunnel portals need special clipping
+	bool tunnel_portal = ist_tunnel()  &&  ist_karten_boden();
+	if (tunnel_portal) {
+		// pretend tunnel portal is connected to the inside
+		ribi |= ribi_t::reverse_single(ribi) & (corner_se(slope)>0 ?  ribi_t::southeast : ribi_t::northwest);
+	}
 	// clip
 	const int hgt_step = tile_raster_scale_y( TILE_HEIGHT_STEP, raster_tile_width);
 	// .. nonconvex n/w if not both n/w are active and if we have back image
@@ -1433,7 +1426,7 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 	}
 	if(  ribi & ribi_t::north  ) {
 		const int dh = corner_nw(slope) * hgt_step;
-		add_poly_clip( xpos + raster_tile_width - 1, ypos + 3 * raster_tile_width / 4 - 1 - dh, xpos + raster_tile_width / 2 + 1, ypos + raster_tile_width / 2 - dh, ribi_t::north | non_convex CLIP_NUM_PAR );
+		add_poly_clip( xpos + raster_tile_width, ypos + 3 * raster_tile_width / 4 - dh, xpos + raster_tile_width / 2, ypos + raster_tile_width / 2 - dh, ribi_t::north | non_convex CLIP_NUM_PAR );
 	}
 	if(  ribi & ribi_t::east  ) {
 		const int dh = corner_se(slope) * hgt_step;
@@ -1441,11 +1434,17 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 	}
 	if(  ribi & ribi_t::south  ) {
 		const int dh = corner_se(slope) * hgt_step;
-		add_poly_clip( xpos, ypos + 3 * raster_tile_width / 4 + 1 - dh, xpos + raster_tile_width / 2, ypos + raster_tile_width + 1 - dh, ribi_t::south|16  CLIP_NUM_PAR );
+		add_poly_clip( xpos- 1, ypos + 3 * raster_tile_width / 4  - dh, xpos + raster_tile_width / 2 - 1, ypos + raster_tile_width  - dh, ribi_t::south|16  CLIP_NUM_PAR );
 	}
+
 	// display background
+	if (!tunnel_portal) {
+		activate_ribi_clip( (ribi_t::northwest & ribi) | 16 CLIP_NUM_PAR );	}
+	else {
+		// also clip along the upper edge of the tunnel tile
+		activate_ribi_clip( ribi | 16 CLIP_NUM_PAR );
+	}
 	// get offset of first vehicle
-	activate_ribi_clip( (ribi_t::northwest & ribi) | 16 CLIP_NUM_PAR );
 	const uint8 offset_vh = display_obj_bg( xpos, ypos, is_global, false, visible CLIP_NUM_PAR );
 	if(  !visible  ) {
 		// end of clipping
@@ -1457,7 +1456,9 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 	if(  ribi & ribi_t::west  ) {
 		grund_t *gr;
 		if(  get_neighbour( gr, invalid_wt, ribi_t::west )  ) {
-			gr->display_obj_vh( xpos - raster_tile_width / 2, ypos - raster_tile_width / 4 - tile_raster_scale_y( (gr->get_hoehe() - pos.z) * TILE_HEIGHT_STEP, raster_tile_width ), 0, ribi_t::west, false CLIP_NUM_PAR );
+			if (!tunnel_portal  ||  gr->is_visible()) {
+				gr->display_obj_vh( xpos - raster_tile_width / 2, ypos - raster_tile_width / 4 - tile_raster_scale_y( (gr->get_hoehe() - pos.z) * TILE_HEIGHT_STEP, raster_tile_width ), 0, ribi_t::west, false CLIP_NUM_PAR );
+			}
 			if(  ribi & ribi_t::south  ) {
 				gr->get_neighbour( gr_nw, invalid_wt, ribi_t::north );
 			}
@@ -1469,7 +1470,9 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 	if(  ribi & ribi_t::north  ) {
 		grund_t *gr;
 		if(  get_neighbour( gr, invalid_wt, ribi_t::north )  ) {
-			gr->display_obj_vh( xpos + raster_tile_width / 2, ypos - raster_tile_width / 4 - tile_raster_scale_y( (gr->get_hoehe() - pos.z) * TILE_HEIGHT_STEP, raster_tile_width ), 0, ribi_t::north, false CLIP_NUM_PAR );
+			if (!tunnel_portal  ||  gr->is_visible()) {
+				gr->display_obj_vh( xpos + raster_tile_width / 2, ypos - raster_tile_width / 4 - tile_raster_scale_y( (gr->get_hoehe() - pos.z) * TILE_HEIGHT_STEP, raster_tile_width ), 0, ribi_t::north, false CLIP_NUM_PAR );
+			}
 			if(  (ribi & ribi_t::east)  &&  (gr_nw == NULL)  ) {
 				gr->get_neighbour( gr_nw, invalid_wt, ribi_t::west );
 			}
@@ -1536,11 +1539,20 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 		gr_se->display_obj_vh( xpos, ypos + raster_tile_width / 2 - tile_raster_scale_y( (gr_se->get_hoehe() - pos.z) * TILE_HEIGHT_STEP, raster_tile_width ), 0, ribi_t::southeast, ontile_se CLIP_NUM_PAR );
 	}
 
-	// end of clipping
-	clear_all_poly_clip( CLIP_NUM_VAR );
-
 	// foreground
+	if (tunnel_portal) {
+		// clip at the upper edge
+		activate_ribi_clip( (ribi & (corner_se(slope)>0 ?  ribi_t::southeast : ribi_t::northwest) )| 16 CLIP_NUM_PAR );
+	}
+	else {
+		clear_all_poly_clip( CLIP_NUM_VAR );
+	}
 	display_obj_fg( xpos, ypos, is_global, offset_fg CLIP_NUM_PAR );
+
+	// end of clipping
+	if (tunnel_portal) {
+		clear_all_poly_clip( CLIP_NUM_VAR );
+	}
 }
 
 
