@@ -197,7 +197,6 @@ protected:
 public:
 	enum typ { boden = 1, wasser, fundament, tunnelboden, brueckenboden, monorailboden };
 
-	grund_t(loadsave_t *file);
 	grund_t(koord3d pos);
 
 private:
@@ -627,7 +626,7 @@ public:
 	weg_t *get_weg(waytype_t typ) const {
 		if (weg_t* const w = get_weg_nr(0)) {
 			const waytype_t wt = w->get_waytype();
-			if(wt == typ) {
+			if(wt == typ || (typ == any_wt && wt > 0)) {
 				return w;
 			}
 			else if (wt > typ) {
