@@ -29,7 +29,7 @@
 // remembers last settings
 static uint32 bFilterStates[MAX_PLAYER_COUNT];
 
-#define BUTTONSPACE 14
+#define BUTTONSPACE max(D_BUTTON_HEIGHT, LINESPACE)
 
 // @author hsiegeln
 const char *money_frame_t::cost_type_name[MAX_PLAYER_COST_BUTTON] =
@@ -86,7 +86,9 @@ const uint8 money_frame_t::cost_type[3*MAX_PLAYER_COST_BUTTON] =
 };
 
 
-/* order has to be same as in enum transport_type in file simtypes.h */
+/* order has to be same as in enum transport_type in file finance.h */
+/* Also these have to match the strings in simline_t::linetype2name! */
+/* (and it is sad that the order between those do not match ...) */
 const char * money_frame_t::transport_type_values[TT_MAX] = {
 	"All",
 	"Truck",
@@ -128,7 +130,7 @@ sint64 money_frame_t::get_statistics_value(int tt, uint8 type, int yearmonth, bo
 void money_frame_t::update_label(gui_label_t &label, char *buf, int transport_type, uint8 type, int yearmonth, int label_type)
 {
 	sint64 value = get_statistics_value(transport_type, type, yearmonth, year_month_tabs.get_active_tab_index()==1);
-	PIXVAL color = value >= 0 ? (value > 0 ? MONEY_PLUS : color_idx_to_rgb(COL_YELLOW)) : MONEY_MINUS;
+	PIXVAL color = value >= 0 ? (value > 0 ? MONEY_PLUS : SYSCOL_TEXT_UNUSED) : MONEY_MINUS;
 
 	if (label_type == MONEY) {
 		const double cost = value / 100.0;
@@ -214,13 +216,13 @@ money_frame_t::money_frame_t(player_t *player)
 		vtmoney(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
 		money(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
 		margin(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
-		transport(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::right),
-		old_transport(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::right),
+		transport(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
+		old_transport(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
 		toll(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
 		old_toll(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
 		maintenance_label("This Month",SYSCOL_TEXT_HIGHLIGHT, gui_label_t::right),
 		maintenance_money(NULL, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::money),
-		warn("", color_idx_to_rgb(COL_YELLOW), gui_label_t::left),
+		warn("", SYSCOL_TEXT_STRONG, gui_label_t::left),
 		scenario("", SYSCOL_TEXT, gui_label_t::left),
 		transport_type_option(0),
 		headquarter_view(koord3d::invalid, scr_size(120, 64))
@@ -232,12 +234,24 @@ money_frame_t::money_frame_t(player_t *player)
 
 	this->player = player;
 
-	const scr_coord_val top =  30;
-	const scr_coord_val left = 12;
+	const scr_coord_val top0 = D_MARGIN_TOP;  // first row of elements
+	const scr_coord_val left = D_MARGIN_LEFT;
 
 	const scr_coord_val tyl_x = left+140+55;
 	const scr_coord_val lyl_x = left+240+55;
 
+	scr_coord_val tab_y = top0; // tabs
+
+	// scenario name
+	if(player->get_player_nr()!=1  &&  welt->get_scenario()->active()) {
+		scenario.set_pos( scr_coord(top0, D_MARGIN_LEFT) );
+		welt->get_scenario()->update_scenario_texts();
+		scenario.set_text( welt->get_scenario()->description_text );
+		add_component(&scenario);
+		tab_y += LINESPACE + D_V_SPACE;
+	}
+	scr_coord_val top = tab_y  + D_TAB_HEADER_HEIGHT + D_V_SPACE + BUTTONSPACE; // second row of buttons
+	top += (BUTTONSPACE-LINESPACE) / 2;
 	// left column
 	tylabel.set_pos(scr_coord(left+120,top-1*BUTTONSPACE));
 	tylabel.set_width(tyl_x-left-120+25);
@@ -245,13 +259,15 @@ money_frame_t::money_frame_t(player_t *player)
 	lylabel.set_width(lyl_x+25-lylabel.get_pos().x);
 
 	//transport.set_pos(scr_coord(tyl_x+19, top+0*BUTTONSPACE));
-	transport.align_to(&tylabel,ALIGN_LEFT,scr_coord(0,top));
-	transport.set_width(tylabel.get_size().w);
+	//transport.align_to(&tylabel,ALIGN_LEFT,scr_coord(0,top));
+	//transport.set_width(tylabel.get_size().w);
 
 	//old_transport.set_pos(scr_coord(lyl_x+19, top+0*BUTTONSPACE));
-	old_transport.align_to(&lylabel,ALIGN_LEFT,scr_coord(0,top));
-	old_transport.set_width(lylabel.get_size().w);
+	//old_transport.align_to(&lylabel,ALIGN_LEFT,scr_coord(0,top));
+	//old_transport.set_width(lylabel.get_size().w);
 
+	transport.set_pos(scr_coord(tyl_x,top+0*BUTTONSPACE));
+	old_transport.set_pos(scr_coord(lyl_x,top+0*BUTTONSPACE));
 	imoney.set_pos(scr_coord(tyl_x,top+1*BUTTONSPACE));
 	old_imoney.set_pos(scr_coord(lyl_x,top+1*BUTTONSPACE));
 	vrmoney.set_pos(scr_coord(tyl_x,top+2*BUTTONSPACE));
@@ -270,10 +286,10 @@ money_frame_t::money_frame_t(player_t *player)
 	old_tmoney.set_pos(scr_coord(lyl_x,top+8*BUTTONSPACE));
 
 	// right column
-	maintenance_label.set_pos(scr_coord(left+340+80-maintenance_label.get_size().w, top+2*BUTTONSPACE-2));
-	maintenance_money.set_pos(scr_coord(left+340+55, top+3*BUTTONSPACE));
+	maintenance_label.set_pos(scr_coord(left+335+120+D_H_SPACE, top+2*BUTTONSPACE));
+	maintenance_money.set_pos(scr_coord(left+335+120+D_H_SPACE, top+3*BUTTONSPACE));
 
-	tylabel2.set_pos(scr_coord(left+140+80+335-tylabel2.get_size().w,top+4*BUTTONSPACE-2));
+	tylabel2.set_pos(scr_coord(left+140+80+335-tylabel2.get_size().w,top+4*BUTTONSPACE));
 	gtmoney.set_pos(scr_coord(left+140+335+55, top+5*BUTTONSPACE));
 	vtmoney.set_pos(scr_coord(left+140+335+55, top+6*BUTTONSPACE));
 	margin.set_pos(scr_coord(left+140+335+55, top+7*BUTTONSPACE));
@@ -281,16 +297,10 @@ money_frame_t::money_frame_t(player_t *player)
 
 	// return money or else stuff ...
 	warn.set_pos(scr_coord(left+335, top+9*BUTTONSPACE));
-	if(player->get_player_nr()!=1  &&  welt->get_scenario()->active()) {
-		scenario.set_pos( scr_coord( 10,1 ) );
-		welt->get_scenario()->update_scenario_texts();
-		scenario.set_text( welt->get_scenario()->description_text );
-		add_component(&scenario);
-	}
 
 	//CHART YEAR
 	chart.set_pos(scr_coord(D_MARGIN_LEFT,top+10*BUTTONSPACE));
-	chart.set_size(scr_size(582-D_MARGIN_LEFT-D_MARGIN_RIGHT,340-(top+10*BUTTONSPACE)-D_MARGIN_BOTTOM-D_TITLEBAR_HEIGHT));
+	chart.set_size(scr_size(582-D_MARGIN_LEFT-D_MARGIN_RIGHT,8*BUTTONSPACE));
 	chart.set_dimension(MAX_PLAYER_HISTORY_YEARS, 10000);
 	chart.set_seed(welt->get_last_year());
 	chart.set_background(SYSCOL_CHART_BACKGROUND);
@@ -298,7 +308,7 @@ money_frame_t::money_frame_t(player_t *player)
 
 	//CHART MONTH
 	mchart.set_pos(scr_coord(D_MARGIN_LEFT,top+10*BUTTONSPACE));
-	mchart.set_size(scr_size(582-D_MARGIN_LEFT-D_MARGIN_RIGHT,340-(top+10*BUTTONSPACE)-D_MARGIN_BOTTOM-D_TITLEBAR_HEIGHT));
+	mchart.set_size(scr_size(582-D_MARGIN_LEFT-D_MARGIN_RIGHT,8*BUTTONSPACE));
 	mchart.set_dimension(MAX_PLAYER_HISTORY_MONTHS, 10000);
 	mchart.set_seed(0);
 	mchart.set_background(SYSCOL_CHART_BACKGROUND);
@@ -315,7 +325,7 @@ money_frame_t::money_frame_t(player_t *player)
 	// tab (month/year)
 	year_month_tabs.add_tab( &year_dummy, translator::translate("Years"));
 	year_month_tabs.add_tab( &month_dummy, translator::translate("Months"));
-	year_month_tabs.set_pos(scr_coord(0, LINESPACE-2));
+	year_month_tabs.set_pos(scr_coord(0, tab_y));
 	year_month_tabs.set_size(scr_size(lyl_x+25, D_TAB_HEADER_HEIGHT));
 	add_component(&year_month_tabs);
 
@@ -363,14 +373,14 @@ money_frame_t::money_frame_t(player_t *player)
 
 	if(  player->get_ai_id()!=player_t::HUMAN  ) {
 		// misuse headquarter button for AI configure
-		headquarter.init(button_t::roundbox, "Configure AI", scr_coord(582-12-120, 0), scr_size(120, BUTTONSPACE));
+		headquarter.init(button_t::roundbox, "Configure AI", scr_coord(582-12-120, top0), scr_size(120, BUTTONSPACE));
 		headquarter.add_listener(this);
 		add_component(&headquarter);
 		headquarter.set_tooltip( "Configure AI setttings" );
 	}
 	else if(old_level > 0  ||  hausbauer_t::get_headquarters(0,welt->get_timeline_year_month())!=NULL) {
 
-		headquarter.init(button_t::roundbox, old_pos!=koord::invalid ? "upgrade HQ" : "build HQ", scr_coord(582-12-120, 0), scr_size(120, BUTTONSPACE));
+		headquarter.init(button_t::roundbox, old_pos!=koord::invalid ? "upgrade HQ" : "build HQ", scr_coord(582-12-120, top0), scr_size(120, BUTTONSPACE));
 		headquarter.add_listener(this);
 		add_component(&headquarter);
 		headquarter.set_tooltip( NULL );
@@ -389,10 +399,11 @@ money_frame_t::money_frame_t(player_t *player)
 	if(old_pos!=koord::invalid) {
 		headquarter_view.set_location( welt->lookup_kartenboden( player->get_headquarter_pos() )->get_pos() );
 	}
-	headquarter_view.set_pos( scr_coord(582-12-120, BUTTONSPACE) );
+	headquarter_view.set_pos( scr_coord(582-12-120, top0 + BUTTONSPACE) );
 	add_component(&headquarter_view);
 
 	// add filter buttons
+	top -= (BUTTONSPACE-LINESPACE) / 2;
 	for(int ibutton=0;  ibutton<9;  ibutton++) {
 		filterButtons[ibutton].init(button_t::box, cost_type_name[ibutton], scr_coord(left, top+ibutton*BUTTONSPACE-2), scr_size(120, BUTTONSPACE));
 		filterButtons[ibutton].add_listener(this);
@@ -418,15 +429,17 @@ money_frame_t::money_frame_t(player_t *player)
 		}
 	}
 
-	transport_type_c.set_pos( scr_coord(left+335-12-2, 0) );
+	transport_type_c.set_pos( scr_coord(left+335-12-2, top0) );
 	transport_type_c.set_size( scr_size(116,D_BUTTON_HEIGHT) );
-	transport_type_c.set_max_size( scr_size( 116, 1*BUTTONSPACE ) );
+	int h = D_BUTTON_HEIGHT;
 	for(int i=0, count=0; i<TT_MAX; ++i) {
 		if (!is_chart_table_zero(i)) {
 			transport_type_c.append_element( new gui_scrolled_list_t::const_text_scrollitem_t(translator::translate(transport_type_values[i]), SYSCOL_TEXT));
 			transport_types[ count++ ] = i;
+			h += LINESPACE;
 		}
 	}
+	transport_type_c.set_max_size( scr_size( 116, h ) );
 	transport_type_c.set_selection(0);
 	transport_type_c.set_focusable( false );
 	add_component(&transport_type_c);
@@ -434,7 +447,7 @@ money_frame_t::money_frame_t(player_t *player)
 
 	set_focus( &transport_type_c );
 
-	set_windowsize(scr_size(582, 340));
+	set_windowsize(scr_size(582, top + 20*BUTTONSPACE));
 }
 
 
@@ -503,7 +516,7 @@ void money_frame_t::draw(scr_coord pos, scr_size size)
 		tstrncpy(str_buf[15], translator::translate("Net wealth near zero"), lengthof(str_buf[15]) );
 	}
 	else if(  player->get_account_overdrawn()  ) {
-		warn.set_color( color_idx_to_rgb(COL_YELLOW) );
+		warn.set_color( SYSCOL_TEXT_STRONG );
 		sprintf( str_buf[15], translator::translate("On loan since %i month(s)"), player->get_account_overdrawn() );
 	}
 	else {
@@ -636,7 +649,7 @@ uint32 money_frame_t::get_rdwr_id()
 
 void money_frame_t::rdwr( loadsave_t *file )
 {
-	bool monthly = mchart.is_visible();;
+	bool monthly = mchart.is_visible();
 	file->rdwr_bool( monthly );
 
 	// button state already collected
