@@ -319,6 +319,9 @@ SOCKET network_open_address(char const* cp, char const*& err)
  */
 bool network_init_server( int port )
 {
+	if (  port==0  ) {
+		dbg->fatal( "network_init_server()", "Cannot host on port 0!" );
+	}
 	// First activate network
 	if (  !network_initialize()  ) {
 		dbg->fatal( "network_init_server()", "Failed to initialize network!" );
@@ -616,11 +619,11 @@ bool network_check_server_connection()
 
 // send data to all PLAYING clients
 // nwc is invalid after the call
-void network_send_all(network_command_t* nwc, bool exclude_us )
+void network_send_all(network_command_t* nwc, bool exclude_us, uint8 player_nr)
 {
 	if (nwc) {
 		nwc->prepare_to_send();
-		socket_list_t::send_all(nwc, true);
+		socket_list_t::send_all(nwc, true, player_nr);
 		if(  !exclude_us  &&  network_server_port  ) {
 			// I am the server
 			nwc->get_packet()->sent_by_server();
@@ -800,5 +803,151 @@ void network_core_shutdown()
 	network_active = false;
 #ifndef NETTOOL
 	env_t::networkmode = false;
+	network_server_port = 0;	// this also sets ent_t::server to zero
 #endif
 }
+
+
+/* The following helper routines will be  used with the easy-server setup, to host machines behind
+ * routers with frequently changing IP addresses.
+ */
+#ifndef NETTOOL
+
+#include "../utils/cbuffer_t.h"
+#include "network_file_transfer.h"
+
+bool get_external_IP( cbuffer_t &myIPaddr )
+{
+	myIPaddr.clear();
+	// query "simutrans-forum.de/get_IP.php" for IP (faster than asking router)
+	const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
+	return err==NULL;
+}
+
+#ifdef USE_UPNP
+/*
+ **** The following functions are used to open ports in UPnP router and will query the IP address ****
+ **** So it will become much easier to set up network games at home.
+ */
+
+extern "C" {
+#define MINIUPNPC_DECLSPEC_H_INCLUDED
+#define MINIUPNP_LIBSPEC extern
+
+//#define MINIUPNP_STATICLIB
+#include <miniupnpc/miniupnpc.h>
+#include <miniupnpc/upnpcommands.h>
+}
+
+#if MINIUPNPC_API_VERSION < 14
+#define upnpDiscover(a,b,c,d,e,f,g) upnpDiscover(a,b,c,d,e,g)
+#define UPNP_LOCAL_PORT_ANY 0
+#endif
+
+bool prepare_for_server( char *externalIPAddress, int port )
+{
+	char lanaddr[64] = "unset";	/* my ip address on the LAN */
+	int error = 0;
+	const char *multicastif = 0;
+	const char *minissdpdpath = 0;
+	int localport = UPNP_LOCAL_PORT_ANY;
+	int ipv6 = 0; // probably not needed for IPv6 ever ...
+	unsigned char ttl = 2; (void)ttl; /* defaulting to 2 */
+	struct UPNPDev *devlist = 0;
+	bool has_IP = false;
+
+	if(  (devlist = upnpDiscover( 2000, multicastif, minissdpdpath, localport, ipv6, ttl, &error ))  ) {
+		struct UPNPUrls urls;
+		struct IGDdatas data;
+
+		UPNP_GetValidIGD( devlist, &urls, &data, lanaddr, sizeof(lanaddr) );
+		// this could query the connection status
+//		if(  UPNP_GetStatusInfo( urls->controlURL, data->first.servicetype, status, &uptime, lastconnerr) == UPNPCOMMAND_SUCCESS  ) {
+//		}
+		// but we must know our IP address first
+		if(  UPNP_GetExternalIPAddress(urls.controlURL, data.first.servicetype, externalIPAddress) ==  UPNPCOMMAND_SUCCESS  ) {
+			// this is our ID (at least the routes tells us this)
+			char eport[19];
+			char *iport = eport;
+			sprintf( eport, "%d", port );
+			// setting up tcp redirect forever (last parameter "0")
+			if(  UPNP_AddPortMapping(urls.controlURL, data.first.servicetype, eport, iport, lanaddr, "simutrans", "TCP", 0, "0")  ==  UPNPCOMMAND_SUCCESS  ) {
+				// ok, we have our ID and redirected a port to us
+				has_IP = true;
+			}
+			else {
+				dbg->warning( "prepare_for_server()", "Could not redirect port (but may be still ok" );
+				has_IP = true;
+			}
+		}
+		FreeUPNPUrls(&urls);
+	}
+	freeUPNPDevlist(devlist);
+
+	if(  !has_IP  ) {
+		cbuffer_t myIPaddr;
+		// lets get IP by query "simutrans-forum.de/get_IP.php" for IP and assume that the redirection is working
+		const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
+		if(  !err  ) {
+			has_IP = true;
+			strcpy( externalIPAddress, myIPaddr.get_str() );
+		}
+	}
+	return has_IP;
+}
+
+
+// removes the redirect (or do nothing)
+void remove_port_forwarding( int port )
+{
+	if(  port <= 0  ||  env_t::easy_server != 1  ) {
+		return;
+	}
+
+	char lanaddr[64] = "unset";	/* my ip address on the LAN */
+	char externalIPAddress[64];
+	int error = 0;
+	const char *multicastif = 0;
+	const char *minissdpdpath = 0;
+	int localport = UPNP_LOCAL_PORT_ANY;
+	int ipv6 = 0; // probably not needed for IPv6 ever ...
+	unsigned char ttl = 2; (void)ttl; /* defaulting to 2 */
+	struct UPNPDev *devlist = 0;
+
+	if(  (devlist = upnpDiscover( 2000, multicastif, minissdpdpath, localport, ipv6, ttl, &error ))  ) {
+		struct UPNPUrls urls;
+		struct IGDdatas data;
+
+		UPNP_GetValidIGD( devlist, &urls, &data, lanaddr, sizeof(lanaddr) );
+		// we must know our IP address first
+		if(  UPNP_GetExternalIPAddress(urls.controlURL, data.first.servicetype, externalIPAddress) ==  UPNPCOMMAND_SUCCESS  ) {
+			// this is our ID (at least the routes tells us this)
+			char eport[19];
+			sprintf( eport, "%d", port );
+			// setting up tcp redirect forever (last parameter "0")
+			UPNP_DeletePortMapping(urls.controlURL, data.first.servicetype, eport, "TCP", NULL);
+		}
+		FreeUPNPUrls(&urls);
+	}
+	freeUPNPDevlist(devlist);
+}
+#else
+// or we jsut get only our IP and hope we are not behind a router ...
+
+bool prepare_for_server( char *externalIPAddress, int )
+{
+	cbuffer_t myIPaddr;
+	// lets get IP by query "simutrans-forum.de/get_IP.php" for IP and assume that the redirection is working
+	const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
+	if(  !err  ) {
+		strcpy( externalIPAddress, myIPaddr.get_str() );
+		return true;
+	}
+	return false;
+}
+
+void remove_port_forwarding( int )
+{
+}
+#endif
+#endif // not NETTOOL
