@@ -725,3 +725,18 @@ const roadsign_desc_t *roadsign_t::roadsign_search(roadsign_desc_t::types const
 	}
 	return NULL;
 }
+
+
+const vector_tpl<const roadsign_desc_t*>& roadsign_t::get_available_signs(const waytype_t wt)
+{
+	static vector_tpl<const roadsign_desc_t*> dummy;
+	dummy.clear();
+	const uint16 time = welt->get_timeline_year_month();
+	FOR(stringhashtable_tpl<roadsign_desc_t const*>, const& i, table) {
+		roadsign_desc_t const* const desc = i.value;
+		if(  desc->is_available(time)  &&  desc->get_wtyp()==wt) {
+			dummy.append(desc);
+		}
+	}
+	return dummy;
+}
