@@ -55,6 +55,12 @@ settings_t::settings_t() :
 
 	show_pax = true;
 
+	// default maximum length of convoi
+	max_rail_convoi_length = 24;
+	max_road_convoi_length = 4;
+	max_ship_convoi_length = 4;
+	max_air_convoi_length = 1;
+
 	// default climate zones
 	set_default_climates( );
 	winter_snowline = 7;	// not mediterranean
@@ -178,8 +184,13 @@ settings_t::settings_t() :
 	 */
 	pak_diagonal_multiplier = 724;
 
-	// assume single level is enough
-	way_height_clearance = 1;
+	// read default from env_t
+	// should be set in simmain.cc (taken from pak-set simuconf.tab
+	way_height_clearance = env_t::default_settings.get_way_height_clearance();
+	if (way_height_clearance < 0  ||  way_height_clearance >2) {
+		// if outside bounds, then set to default = 1
+		way_height_clearance = 1;
+	}
 
 	strcpy( language_code_names, "en" );
 
@@ -445,9 +456,15 @@ void settings_t::rdwr(loadsave_t *file)
 
 		// climate borders
 		if(file->get_version()>=91000) {
+			if(  file->get_version()<120006  ) {
+				climate_borders[arctic_climate] -= groundwater;
+			}
 			for(  int i=0;  i<8;  i++ ) {
 				file->rdwr_short(climate_borders[i] );
 			}
+			if(  file->get_version()<120006  ) {
+				climate_borders[arctic_climate] += groundwater;
+			}
 			file->rdwr_short(winter_snowline );
 		}
 
@@ -792,6 +809,12 @@ void settings_t::rdwr(loadsave_t *file)
 		if(  file->get_version() > 120003  ) {
 			file->rdwr_bool(disable_make_way_public);
 		}
+		if(  file->get_version() > 120005  ) {
+			file->rdwr_byte(max_rail_convoi_length);
+			file->rdwr_byte(max_road_convoi_length);
+			file->rdwr_byte(max_ship_convoi_length);
+			file->rdwr_byte(max_air_convoi_length);
+		}
 		// otherwise the default values of the last one will be used
 	}
 }
@@ -823,6 +846,13 @@ void settings_t::parse_simuconf(tabfile_t& simuconf, sint16& disp_width, sint16&
 	}
 #endif
 
+	//check for fontname, must be a valid name!
+	const char *fname = contents.get_string( "fontname", env_t::fontname.c_str() );
+	if(  FILE *f=fopen(fname,"r")  ) {
+		fclose(f);
+		env_t::fontname = fname;
+	}
+
 	env_t::water_animation = contents.get_int("water_animation_ms", env_t::water_animation );
 	env_t::ground_object_probability = contents.get_int("random_grounds_probability", env_t::ground_object_probability );
 	env_t::moving_object_probability = contents.get_int("random_wildlife_probability", env_t::moving_object_probability );
@@ -884,6 +914,7 @@ void settings_t::parse_simuconf(tabfile_t& simuconf, sint16& disp_width, sint16&
 	env_t::reload_and_save_on_quit = contents.get_int("reload_and_save_on_quit", env_t::reload_and_save_on_quit );
 
 	env_t::server_announce = contents.get_int("announce_server", env_t::server_announce );
+	env_t::server_announce = contents.get_int("server_port", env_t::server_port );
 	env_t::server_announce = contents.get_int("server_announce", env_t::server_announce );
 	env_t::server_announce_interval = contents.get_int("server_announce_intervall", env_t::server_announce_interval );
 	env_t::server_announce_interval = contents.get_int("server_announce_interval", env_t::server_announce_interval );
@@ -1387,6 +1418,11 @@ void settings_t::parse_simuconf(tabfile_t& simuconf, sint16& disp_width, sint16&
 
 	with_private_paks = contents.get_int("with_private_paks", with_private_paks)!=0;
 
+	max_rail_convoi_length = contents.get_int("max_rail_convoi_length",max_rail_convoi_length);
+	max_road_convoi_length = contents.get_int("max_road_convoi_length",max_road_convoi_length);
+	max_ship_convoi_length = contents.get_int("max_ship_convoi_length",max_ship_convoi_length);
+	max_air_convoi_length = contents.get_int("max_air_convoi_length",max_air_convoi_length);
+
 	// Default pak file path
 	objfilename = ltrim(contents.get_string("pak_file_path", "" ) );
 
