@@ -46,6 +46,7 @@ depot_t::depot_t(loadsave_t *file) : gebaeude_t()
 	}
 	all_depots.append(this);
 	selected_filter = VEHICLE_FILTER_RELEVANT;
+	selected_sort_by = SORT_BY_DEFAULT;
 	last_selected_line = linehandle_t();
 	command_pending = false;
 }
@@ -56,6 +57,7 @@ depot_t::depot_t(koord3d pos, player_t *player, const building_tile_desc_t *t) :
 {
 	all_depots.append(this);
 	selected_filter = VEHICLE_FILTER_RELEVANT;
+	selected_sort_by = SORT_BY_DEFAULT;
 	last_selected_line = linehandle_t();
 	command_pending = false;
 }
@@ -381,6 +383,9 @@ bool depot_t::start_all_convoys()
 	return (convois.get_count() == 0);
 }
 
+// implementation in simtool.cc
+bool scenario_check_convoy(karte_t *welt, player_t *player, convoihandle_t cnv, depot_t* depot, bool local);
+
 
 bool depot_t::start_convoi(convoihandle_t cnv, bool local_execution)
 {
@@ -419,6 +424,9 @@ bool depot_t::start_convoi(convoihandle_t cnv, bool local_execution)
 				create_win( new news_img(buf), w_time_delete, magic_none);
 			}
 		}
+		else if (!scenario_check_convoy(welt, get_owner(), cnv, this, local_execution) ) {
+			// not allowed by scenario
+		}
 		else {
 			// convoi can start now
 			cnv->start();
@@ -612,5 +620,17 @@ void depot_t::update_all_win()
 
 unsigned bahndepot_t::get_max_convoi_length() const
 {
-	return convoi_t::max_rail_vehicle;
+	return welt->get_settings().get_max_rail_convoi_length();
+}
+unsigned strassendepot_t::get_max_convoi_length() const
+{
+	return welt->get_settings().get_max_road_convoi_length();
+}
+unsigned schiffdepot_t::get_max_convoi_length() const
+{
+	return welt->get_settings().get_max_ship_convoi_length();
+}
+unsigned airdepot_t::get_max_convoi_length() const
+{
+	return welt->get_settings().get_max_air_convoi_length();
 }
