@@ -15,6 +15,7 @@
 
 #define VEHICLE_FILTER_RELEVANT 1
 #define VEHICLE_FILTER_GOODS_OFFSET 2
+#define SORT_BY_DEFAULT 0
 
 
 class karte_t;
@@ -54,6 +55,9 @@ public:
 	// Last selected vehicle filter
 	int selected_filter;
 
+	// Last selected vehicle sort
+	int selected_sort_by;
+
 	// finds the next/previous depot relative to the current position
 	static depot_t *find_depot( koord3d start, const obj_t::typ depot_type, const player_t *player, bool next);
 
@@ -355,7 +359,7 @@ public:
 	int get_y_placement() const { return -25; }
 	int get_x_grid() const { return 24; }
 	int get_y_grid() const { return 24; }
-	unsigned get_max_convoi_length() const { return 4; }
+	unsigned get_max_convoi_length() const;
 
 	obj_t::typ get_typ() const { return strassendepot; }
 	const char *get_name() const {return "Strassendepot";}
@@ -392,7 +396,7 @@ public:
 	int get_x_grid() const { return 60; }
 	int get_y_grid() const { return 46; }
 
-	unsigned get_max_convoi_length() const { return 4; }
+	unsigned get_max_convoi_length() const;
 	obj_t::typ get_typ() const { return schiffdepot; }
 	const char *get_name() const {return "Schiffdepot";}
 };
@@ -422,7 +426,7 @@ public:
 	int get_y_placement() const {return -23; }
 	int get_x_grid() const { return 36; }
 	int get_y_grid() const { return 36; }
-	unsigned get_max_convoi_length() const { return 1; }
+	unsigned get_max_convoi_length() const;
 
 	obj_t::typ get_typ() const { return airdepot; }
 	const char *get_name() const {return "Hangar";}
