@@ -25,7 +25,7 @@ KOORD_VAL base_tile_raster_width = 16; // original
 PIXVAL specialcolormap_all_day[256];
 
 
-uint32 get_color_rgb(uint8 idx)
+uint32 get_color_rgb(uint8)
 {
 	return 0;
 }
@@ -92,15 +92,6 @@ void display_set_actual_width(KOORD_VAL)
 {
 }
 
-int display_get_light()
-{
-	return 0;
-}
-
-void display_set_light(int)
-{
-}
-
 void display_day_night_shift(int)
 {
 }
@@ -234,6 +225,12 @@ display_alpha_proc display_alpha = display_base_img_alpha;
 
 signed short current_tile_raster_width = 0;
 
+PIXVAL display_blend_colors(PIXVAL, PIXVAL, int)
+{
+	return 0;
+}
+
+
 void display_blend_wh_rgb(KOORD_VAL, KOORD_VAL, KOORD_VAL, KOORD_VAL, PIXVAL, int )
 {
 }
@@ -273,7 +270,7 @@ sint32 get_prev_char(const char*, sint32 pos)
 	return pos - 1;
 }
 
-KOORD_VAL display_get_char_width(utf16)
+KOORD_VAL display_get_char_width(utf32)
 {
 	return 0;
 }
@@ -283,12 +280,12 @@ KOORD_VAL display_get_char_max_width(const char*, size_t)
 	return 0;
 }
 
-unsigned short get_next_char_with_metrics(const char* &, unsigned char &, unsigned char &)
+utf32 get_next_char_with_metrics(const char* &, unsigned char &, unsigned char &)
 {
 	return 0;
 }
 
-unsigned short get_prev_char_with_metrics(const char* &, const char *const, unsigned char &, unsigned char &)
+utf32 get_prev_char_with_metrics(const char* &, const char *const, unsigned char &, unsigned char &)
 {
 	return 0;
 }
