@@ -107,7 +107,7 @@ void player_t::book_construction_costs(player_t * const player, const sint64 amo
 }
 
 
-sint32 player_t::add_maintenance(sint32 change, waytype_t const wt)
+sint64 player_t::add_maintenance(sint64 change, waytype_t const wt)
 {
 	int tmp = 0;
 #ifdef MULTI_THREAD
@@ -460,7 +460,7 @@ void player_t::ai_bankrupt()
 
 		cnv->self_destruct();
 		// convois not in depots must step to really get rid of them
-		if(  cnv->get_state() != convoi_t::INITIAL  ) {
+		if(  cnv.is_bound()  &&  cnv->get_state() != convoi_t::INITIAL  ) {
 			cnv->step();
 		}
 
@@ -917,13 +917,7 @@ void player_t::tell_tool_result(tool_t *tool, koord3d, const char *err)
 			sound_play(SFX_FAILURE);
 			// look for coordinate in error message
 			// syntax: either @x,y or (x,y)
-			koord pos = message_t::get_coord_from_text(err);
-			if (pos != koord::invalid) {
-				create_win( new news_loc(err, pos), w_time_delete, magic_none);
-			}
-			else {
-				create_win( new news_img(err), w_time_delete, magic_none);
-			}
+			open_error_msg_win(err);
 		}
 	}
 }
