@@ -198,7 +198,7 @@ void road_user_t::rdwr(loadsave_t *file)
 		set_xoff( ddx-(16-i)*dx );
 		set_yoff( ddy-(16-i)*dy );
 		if(file->is_loading()) {
-			if(dx*dy) {
+			if(dx && dy) {
 				steps = min( VEHICLE_STEPS_PER_TILE - 1, VEHICLE_STEPS_PER_TILE - 1 - (i*16) );
 				steps_next = VEHICLE_STEPS_PER_TILE - 1;
 			}
@@ -329,6 +329,7 @@ private_car_t::private_car_t(loadsave_t *file) :
 {
 	rdwr(file);
 	ms_traffic_jam = 0;
+	calc_disp_lane();
 	if(desc) {
 		welt->sync.add(this);
 	}
@@ -341,7 +342,7 @@ private_car_t::private_car_t(grund_t* gr, koord const target) :
 	desc(liste_timeline.empty() ? 0 : pick_any_weighted(liste_timeline))
 {
 	pos_next_next = koord3d::invalid;
-	time_to_life = welt->get_settings().get_stadtauto_duration() << welt->ticks_per_world_month_shift;
+	time_to_life = welt->get_settings().get_stadtauto_duration() << 20;  // ignore welt->ticks_per_world_month_shift;
 	current_speed = 48;
 	ms_traffic_jam = 0;
 #ifdef DESTINATION_CITYCARS
@@ -350,6 +351,7 @@ private_car_t::private_car_t(grund_t* gr, koord const target) :
 	(void)target;
 #endif
 	calc_image();
+	calc_disp_lane();
 	welt->buche( +1, karte_t::WORLD_CITYCARS );
 }
 
@@ -460,7 +462,6 @@ void private_car_t::rdwr(loadsave_t *file)
 		file->rdwr_byte(tiles_overtaking);
 		set_tiles_overtaking( tiles_overtaking );
 	}
-
 	// do not start with zero speed!
 	current_speed ++;
 }
@@ -622,13 +623,14 @@ bool private_car_t::ist_weg_frei(grund_t *gr)
 void private_car_t::enter_tile(grund_t* gr)
 {
 #ifdef DESTINATION_CITYCARS
-	if(target!=koord::invalid  &&  koord_distance(pos_next.get_2d(),target)<10) {
+	if(  target!=koord::invalid  &&  koord_distance(pos_next.get_2d(),target)<10  ) {
 		// delete it ...
 		time_to_life = 0;
-		pedestrian_t::generate_pedestrians_at(welt, get_pos(), 2);
+		// was generating pedestrians gere, but not possible with new sync system
 	}
 #endif
 	vehicle_base_t::enter_tile(gr);
+	calc_disp_lane();
 	gr->get_weg(road_wt)->book(1, WAY_STAT_CONVOIS);
 }
 
@@ -857,6 +859,18 @@ void private_car_t::get_screen_offset( int &xoff, int &yoff, const sint16 raster
 }
 
 
+void private_car_t::calc_disp_lane()
+{
+	// driving in the back or the front
+	ribi_t::ribi test_dir = welt->get_settings().is_drive_left() ? ribi_t::northeast : ribi_t::southwest;
+	disp_lane = get_direction() & test_dir ? 1 : 3;
+}
+
+void private_car_t::rotate90()
+{
+	road_user_t::rotate90();
+	calc_disp_lane();
+}
 
 /**
  * conditions for a city car to overtake another overtaker.
