@@ -16,12 +16,14 @@
 #include <wingdi.h>
 #include <mmsystem.h>
 #include <imm.h>
+#include <commdlg.h>
 
 #ifdef __CYGWIN__
 extern int __argc;
 extern char **__argv;
 #endif
 
+#include "simconst.h"
 #include "display/simgraph.h"
 #include "simdebug.h"
 #include "gui/simwin.h"
@@ -38,9 +40,6 @@ extern char **__argv;
 #	define GET_WHEEL_DELTA_WPARAM(wparam) ((short)HIWORD(wparam))
 #endif
 
-// 16 Bit may be much slower than 15 unfortunately on some hardware
-#define USE_16BIT_DIB
-
 #include "simmem.h"
 #include "simsys_w32_png.h"
 #include "simversion.h"
@@ -126,15 +125,14 @@ static void create_window(DWORD const ex_style, DWORD const style, int const x,
 	RECT r = { 0, 0, w, h };
 	AdjustWindowRectEx(&r, style, false, ex_style);
 
-#if 0
-	// Try with a wide character window; need the title with full width
-	WCHAR *wSIM_TITLE = new wchar_t[lengthof(SIM_TITLE)];
-	size_t convertedChars = 0;
-	mbstowcs( wSIM_TITLE, SIM_TITLE, lengthof(SIM_TITLE) );
+	// Convert UTF-8 to UTF-16.
+	int const size = MultiByteToWideChar(CP_UTF8, MB_ERR_INVALID_CHARS, SIM_TITLE, -1, NULL, 0);
+	LPWSTR const wSIM_TITLE = new WCHAR[size];
+	MultiByteToWideChar(CP_UTF8, 0, SIM_TITLE, -1, wSIM_TITLE, size);
+
 	hwnd = CreateWindowExW(ex_style, L"Simu", wSIM_TITLE, style, x, y, r.right - r.left, r.bottom - r.top, 0, 0, hInstance, 0);
-#else
-	hwnd = CreateWindowExA(ex_style, "Simu", SIM_TITLE, style, x, y, r.right - r.left, r.bottom - r.top, 0, 0, hInstance, 0);
-#endif
+
+	delete[] wSIM_TITLE;
 
 	ShowWindow(hwnd, SW_SHOW);
 	SetTimer( hwnd, 0, 1111, NULL );	// HACK: so windows thinks we are not dead when processing a timer every 1111 ms ...
@@ -145,7 +143,7 @@ static void create_window(DWORD const ex_style, DWORD const style, int const x,
 int dr_os_open(int const w, int const h, int fullscreen)
 {
 	MaxSize.right = ((w*x_scale)/32+15) & 0x7FF0;
-	MaxSize.bottom = (h*y_scale)/32+1;
+	MaxSize.bottom = (h*y_scale)/32;
 
 #ifdef MULTI_THREAD
 	InitializeCriticalSection( &redraw_underway );
@@ -162,7 +160,7 @@ int dr_os_open(int const w, int const h, int fullscreen)
 		settings.dmFields = DM_BITSPERPEL | DM_PELSWIDTH | DM_PELSHEIGHT;
 		settings.dmBitsPerPel = COLOUR_DEPTH;
 		settings.dmPelsWidth  = MaxSize.right;
-		settings.dmPelsHeight = MaxSize.bottom-1;
+		settings.dmPelsHeight = MaxSize.bottom;
 		settings.dmDisplayFrequency = 0;
 
 		if(  ChangeDisplaySettings(&settings, CDS_TEST)!=DISP_CHANGE_SUCCESSFUL  ) {
@@ -182,20 +180,20 @@ int dr_os_open(int const w, int const h, int fullscreen)
 		is_fullscreen = fullscreen;
 	}
 	if(  fullscreen  ) {
-		create_window(WS_EX_TOPMOST, WS_POPUP, 0, 0, MaxSize.right, MaxSize.bottom-1);
+		create_window(WS_EX_TOPMOST, WS_POPUP, 0, 0, MaxSize.right, MaxSize.bottom);
 	}
 	else {
-		create_window(0, WS_OVERLAPPEDWINDOW, CW_USEDEFAULT, CW_USEDEFAULT, MaxSize.right, MaxSize.bottom-1);
+		create_window(0, WS_OVERLAPPEDWINDOW, CW_USEDEFAULT, CW_USEDEFAULT, MaxSize.right, MaxSize.bottom);
 	}
 
 	WindowSize.right  = MaxSize.right;
-	WindowSize.bottom = MaxSize.bottom-1;
+	WindowSize.bottom = MaxSize.bottom;
 
 	AllDib = MALLOCF(BITMAPINFO, bmiColors, 3);
 	BITMAPINFOHEADER& header = AllDib->bmiHeader;
 	header.biSize          = sizeof(BITMAPINFOHEADER);
 	header.biWidth         = (w+15) & 0x7FF0;
-	header.biHeight        = h+1;
+	header.biHeight        = h;
 	header.biPlanes        = 1;
 	header.biBitCount      = COLOUR_DEPTH;
 	header.biCompression   = BI_RGB;
@@ -205,15 +203,15 @@ int dr_os_open(int const w, int const h, int fullscreen)
 	header.biClrUsed       = 0;
 	header.biClrImportant  = 0;
 	DWORD* const masks = (DWORD*)AllDib->bmiColors;
-#ifdef USE_16BIT_DIB
+#ifdef RGB555
+	masks[0]               = 0x01;
+	masks[1]               = 0x02;
+	masks[2]               = 0x03;
+#else
 	header.biCompression   = BI_BITFIELDS;
 	masks[0]               = 0x0000F800;
 	masks[1]               = 0x000007E0;
 	masks[2]               = 0x0000001F;
-#else
-	masks[0]               = 0x01;
-	masks[1]               = 0x02;
-	masks[2]               = 0x03;
 #endif
 
 	return header.biWidth;
@@ -297,10 +295,10 @@ unsigned short *dr_textur_init()
  */
 unsigned int get_system_color(unsigned int r, unsigned int g, unsigned int b)
 {
-#ifdef USE_16BIT_DIB
-	return ((r & 0x00F8) << 8) | ((g & 0x00FC) << 3) | (b >> 3);
-#else
+#ifdef RGB555
 	return ((r & 0x00F8) << 7) | ((g & 0x00F8) << 2) | (b >> 3); // 15 Bit
+#else
+	return ((r & 0x00F8) << 8) | ((g & 0x00FC) << 3) | (b >> 3);
 #endif
 }
 
@@ -406,14 +404,14 @@ void set_pointer(int loading)
  */
 int dr_screenshot(const char *filename, int x, int y, int w, int h)
 {
-#if defined USE_16BIT_DIB
-	int const bpp = COLOUR_DEPTH;
-#else
+#if defined RGB555
 	int const bpp = 15;
+#else
+	int const bpp = COLOUR_DEPTH;
 #endif
 	if (!dr_screenshot_png(filename, w, h, AllDib->bmiHeader.biWidth, (unsigned short*)AllDibData+x+y*AllDib->bmiHeader.biWidth, bpp)) {
 		// not successful => save full screen as BMP
-		if (FILE* const fBmp = fopen(filename, "wb")) {
+		if (FILE* const fBmp = dr_fopen(filename, "wb")) {
 			BITMAPFILEHEADER bf;
 
 			// since the number of drawn pixel can be smaller than the actual width => only use the drawn pixel for bitmap
@@ -490,10 +488,10 @@ LRESULT WINAPI WindowProc(HWND this_hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 					MEMZERO(settings);
 					settings.dmSize = sizeof(settings);
 					settings.dmFields = DM_BITSPERPEL | DM_PELSWIDTH | DM_PELSHEIGHT;
-#if defined USE_16BIT_DIB
-					settings.dmBitsPerPel = COLOUR_DEPTH;
-#else
+#ifdef RGB555
 					settings.dmBitsPerPel = 15;
+#else
+					settings.dmBitsPerPel = COLOUR_DEPTH;
 #endif
 					settings.dmPelsWidth  = MaxSize.right;
 					settings.dmPelsHeight = MaxSize.bottom;
@@ -600,7 +598,7 @@ LRESULT WINAPI WindowProc(HWND this_hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 				sys_event.type = SIM_SYSTEM;
 				sys_event.code = SYSTEM_RESIZE;
 
-				sys_event.mx = ((LOWORD(lParam) + 1)*32)/x_scale;
+				sys_event.mx = (LOWORD(lParam)*32)/x_scale;
 				if (sys_event.mx <= 0) {
 					sys_event.mx = 4;
 				}
