@@ -14,6 +14,7 @@
 #include "gui/simwin.h"
 
 #include "dataobj/translator.h"
+#include "dataobj/scenario.h"
 
 #include "gui/factory_edit.h"
 #include "gui/curiosity_edit.h"
@@ -46,6 +47,8 @@
 #include "gui/server_frame.h"
 #include "gui/schedule_list.h"
 #include "gui/themeselector.h"
+#include "gui/scenario_frame.h"
+#include "gui/scenario_info.h"
 
 class player_t;
 
@@ -57,7 +60,7 @@ public:
 	dialog_help_t() : tool_t(DIALOG_HELP | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Help"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_mainhelp); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		help_frame_t::open_help_on("general.txt");
 		return false;
 	}
@@ -72,7 +75,7 @@ public:
 	dialog_options_t() : tool_t(DIALOG_OPTIONS | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Einstellungen aendern"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_optionen_gui_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(240, 120, new optionen_gui_t(), w_info, magic_optionen_gui_t);
 		return false;
 	}
@@ -87,7 +90,7 @@ public:
 	dialog_minimap_t() : tool_t(DIALOG_MINIMAP | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Reliefkarte"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_reliefmap); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new map_frame_t(), w_info, magic_reliefmap);
 		return false;
 	}
@@ -103,7 +106,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Line Management"); }
 	image_id get_icon(player_t* player_) const OVERRIDE{ return player_->get_player_nr() == 1 ? IMG_EMPTY : icon; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_line_management_t + welt->get_active_player_nr()); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		if (player_->get_player_nr() != welt->get_public_player()->get_player_nr()) {
 			create_win(new schedule_list_gui_t(player_), w_info, magic_line_management_t + player_->get_player_nr());
 		}
@@ -120,7 +123,7 @@ public:
 	dialog_messages_t() : tool_t(DIALOG_MESSAGES | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Mailbox"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_messageframe); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new message_frame_t(), w_info, magic_messageframe);
 		return false;
 	}
@@ -135,7 +138,7 @@ public:
 	dialog_finances_t() : tool_t(DIALOG_FINANCES | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Finanzen"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_finances_t + welt->get_active_player_nr()); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		create_win(new money_frame_t(player_), w_info, magic_finances_t + player_->get_player_nr());
 		return false;
 	}
@@ -150,7 +153,7 @@ public:
 	dialog_players_t() : tool_t(DIALOG_PLAYERS | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Spielerliste"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_ki_kontroll_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(272, 160, new ki_kontroll_t(), w_info, magic_ki_kontroll_t);
 		return false;
 	}
@@ -165,7 +168,7 @@ public:
 	dialog_displayoptions_t() : tool_t(DIALOG_DISPLAYOPTIONS | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Helligk."); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_color_gui_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new color_gui_t(), w_info, magic_color_gui_t);
 		return false;
 	}
@@ -180,7 +183,7 @@ public:
 	dialog_sound_t() : tool_t(DIALOG_SOUND | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Sound"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_sound_kontroll_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new sound_frame_t(), w_info, magic_sound_kontroll_t);
 		return false;
 	}
@@ -195,7 +198,7 @@ public:
 	dialog_language_t() : tool_t(DIALOG_LANGUAGE | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Sprache"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_sprachengui_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new sprachengui_t(), w_info, magic_sprachengui_t);
 		return false;
 	}
@@ -210,7 +213,7 @@ public:
 	dialog_playercolor_t() : tool_t(DIALOG_PLAYERCOLOR | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Farbe"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_farbengui_t); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		create_win(new farbengui_t(player_), w_info, magic_farbengui_t);
 		return false;
 	}
@@ -225,7 +228,7 @@ public:
 	dialog_jump_t() : tool_t(DIALOG_JUMP | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Jump to"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_jump); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new jump_frame_t(), w_info, magic_jump);
 		return false;
 	}
@@ -240,9 +243,19 @@ public:
 	dialog_load_t() : tool_t(DIALOG_LOAD | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Laden"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_load_t); }
-		bool init(player_t*) OVERRIDE{
-		destroy_all_win(true);
-		create_win(new loadsave_frame_t(true), w_info, magic_load_t);
+	bool init(player_t*) OVERRIDE{
+		if(  win_get_magic(magic_save_t)  ) {
+			destroy_win(magic_save_t);
+		}
+		if(  !env_t::server  ) {
+			destroy_all_win(true);
+			create_win(new loadsave_frame_t(true), w_info, magic_load_t);
+		}
+		else {
+			create_win( new loadsave_frame_t(true), w_info, magic_load_t);
+			scr_coord pos = win_get_pos( win_get_magic(magic_load_t) );
+			create_win( pos.x+20, pos.y+20, new news_img("Loading a new game will end the current server session!"), w_no_overlap, magic_none);
+		}
 		return false;
 	}
 	bool exit(player_t*) OVERRIDE{ destroy_win(magic_load_t); return false; }
@@ -255,7 +268,10 @@ public:
 	dialog_save_t() : tool_t(DIALOG_SAVE | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Speichern"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_save_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
+		if(  !env_t::server  ) {
+			destroy_all_win(true);
+		}
 		create_win(new loadsave_frame_t(false), w_info, magic_save_t);
 		return false;
 	}
@@ -263,13 +279,53 @@ public:
 	bool is_init_network_save() const OVERRIDE{ return true; }
 };
 
+// open scenario dialog
+class dialog_scenario_t : public tool_t {
+public:
+	dialog_scenario_t() : tool_t(DIALOG_SCENARIO | DIALOGE_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Load scenario"); }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_load_t); }
+	bool init(player_t*) OVERRIDE{
+		if(  win_get_magic(magic_save_t)  ) {
+			destroy_win(magic_save_t);
+		}
+		if(  !env_t::server  ) {
+			destroy_all_win(true);
+			create_win( new scenario_frame_t(), w_info, magic_load_t );
+		}
+		else {
+			create_win( new scenario_frame_t(), w_info, magic_load_t );
+			scr_coord pos = win_get_pos( win_get_magic(magic_load_t) );
+			create_win( pos.x+20, pos.y+20, new news_img("Loading a new game will end the current server session!"), w_no_overlap, magic_none);
+		}
+		return false;
+	}
+	bool exit(player_t*) OVERRIDE{ destroy_win(magic_load_t); return false; }
+	bool is_init_network_save() const OVERRIDE{ return true; }
+};
+
+// open scenario info dialog
+class dialog_scenario_info_t : public tool_t {
+public:
+	dialog_scenario_info_t() : tool_t(DIALOG_SCENARIO_INFO | DIALOGE_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Scenario"); }
+	image_id get_icon(player_t *) const { return world()->get_scenario()->is_scripted() ? icon : IMG_EMPTY; }
+	bool is_selected() const OVERRIDE{ return win_get_magic(magic_scenario_info); }
+	bool init(player_t*) OVERRIDE{
+		create_win( new scenario_info_t(), w_info, magic_scenario_info );
+		return false;
+	}
+	bool exit(player_t*) OVERRIDE{ destroy_win(magic_scenario_info); return false; }
+	bool is_init_network_save() const OVERRIDE{ return true; }
+};
+
 /* open the list of halt */
 class dialog_list_halt_t : public tool_t {
 public:
 	dialog_list_halt_t() : tool_t(DIALOG_LIST_HALT | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("hl_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_halt_list_t); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		create_win(new halt_list_frame_t(player_), w_info, magic_halt_list_t);
 		return false;
 	}
@@ -284,7 +340,7 @@ public:
 	dialog_list_convoi_t() : tool_t(DIALOG_LIST_CONVOI | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("cl_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_convoi_list + welt->get_active_player_nr()); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		create_win(new convoi_frame_t(player_), w_info, magic_convoi_list + player_->get_player_nr());
 		return false;
 	}
@@ -299,7 +355,7 @@ public:
 	dialog_list_town_t() : tool_t(DIALOG_LIST_TOWN | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("tl_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_citylist_frame_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new citylist_frame_t(), w_info, magic_citylist_frame_t);
 		return false;
 	}
@@ -314,7 +370,7 @@ public:
 	dialog_list_goods_t() : tool_t(DIALOG_LIST_GOODS | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("gl_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_goodslist); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new goods_frame_t(), w_info, magic_goodslist);
 		return false;
 	}
@@ -329,7 +385,7 @@ public:
 	dialog_list_factory_t() : tool_t(DIALOG_LIST_FACTORY | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("fl_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_factorylist); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new factorylist_frame_t(), w_info, magic_factorylist);
 		return false;
 	}
@@ -344,7 +400,7 @@ public:
 	dialog_list_curiosity_t() : tool_t(DIALOG_LIST_CURIOSITY | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("curlist_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_curiositylist); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new curiositylist_frame_t(), w_info, magic_curiositylist);
 		return false;
 	}
@@ -359,7 +415,7 @@ public:
 	dialog_edit_factory_t() : tool_t(DIALOG_EDIT_FACTORY | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("factorybuilder"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_edit_factory); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		if (!is_selected()) {
 			create_win(new factory_edit_frame_t(player_), w_info, magic_edit_factory);
 		}
@@ -376,7 +432,7 @@ public:
 	dialog_edit_attraction_t() : tool_t(DIALOG_EDIT_ATTRACTION | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("curiosity builder"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_edit_attraction); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		if (!is_selected()) {
 			create_win(new curiosity_edit_frame_t(player_), w_info, magic_edit_attraction);
 		}
@@ -393,7 +449,7 @@ public:
 	dialog_edit_house_t() : tool_t(DIALOG_EDIT_HOUSE | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("citybuilding builder"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_edit_house); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		if (!is_selected()) {
 			create_win(new citybuilding_edit_frame_t(player_), w_info, magic_edit_house);
 		}
@@ -411,7 +467,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("baum builder"); }
 	image_id get_icon(player_t *) const { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_edit_tree); }
-		bool init(player_t* player_) OVERRIDE{
+	bool init(player_t* player_) OVERRIDE{
 		if (baum_t::get_count() > 0 && !is_selected()) {
 			create_win(new baum_edit_frame_t(player_), w_info, magic_edit_tree);
 		}
@@ -429,7 +485,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("enlarge map"); }
 	image_id get_icon(player_t *) const { return env_t::networkmode ? IMG_EMPTY : icon; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_bigger_map); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		if (!env_t::networkmode) {
 			destroy_all_win(true);
 			create_win(new enlarge_map_frame_t(), w_info, magic_bigger_map);
@@ -445,7 +501,7 @@ public:
 	dialog_list_label_t() : tool_t(DIALOG_LIST_LABEL | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("labellist_title"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_labellist); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new labellist_frame_t(), w_info, magic_labellist);
 		return false;
 	}
@@ -461,7 +517,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return (!env_t::networkmode || env_t::server) ? translator::translate("Climate Control") : translator::translate("deactivated in online mode"); }
 	image_id get_icon(player_t *) const { return (!env_t::networkmode || env_t::server) ? icon : IMG_EMPTY; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_climate); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		if (!env_t::networkmode || env_t::server) {
 			create_win(new climate_gui_t(&welt->get_settings()), w_info, magic_climate);
 		}
@@ -477,7 +533,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return (!env_t::networkmode || env_t::server) ? translator::translate("Setting") : translator::translate("deactivated in online mode"); }
 	image_id get_icon(player_t *) const { return (!env_t::networkmode || env_t::server) ? icon : IMG_EMPTY; }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_settings_frame_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		if (!env_t::networkmode || env_t::server) {
 			create_win(new settings_frame_t(&welt->get_settings()), w_info, magic_settings_frame_t);
 		}
@@ -492,7 +548,7 @@ public:
 	dialog_gameinfo_t() : tool_t(DIALOG_GAMEINFO | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Game info"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_server_frame_t); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new server_frame_t(), w_info, magic_server_frame_t);
 		return false;
 	}
@@ -507,7 +563,7 @@ public:
 	dialog_themes_t() : tool_t(DIALOG_THEMES | DIALOGE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE{ return translator::translate("Select a theme for display"); }
 	bool is_selected() const OVERRIDE{ return win_get_magic(magic_themes); }
-		bool init(player_t*) OVERRIDE{
+	bool init(player_t*) OVERRIDE{
 		create_win(new themeselector_t(), w_info, magic_themes);
 		return false;
 	}
