@@ -36,6 +36,8 @@ class way_obj_desc_t;
 
 char *tooltip_with_price(const char * tip, sint64 price);
 
+void open_error_msg_win(const char* error);
+
 /************************ general tool *******************************/
 
 // query tile info: default tool
@@ -378,7 +380,6 @@ public:
 
 class tool_build_station_t : public tool_t {
 private:
-	static char toolstring[256];
 	const char *tool_station_building_aux(player_t *, bool, koord3d, const building_desc_t *, sint8 rotation );
 	const char *tool_station_dock_aux(player_t *, koord3d, const building_desc_t * );
 	const char *tool_station_flat_dock_aux(player_t *, koord3d, const building_desc_t *, sint8 );
@@ -398,6 +399,18 @@ public:
 	waytype_t get_waytype() const OVERRIDE;
 };
 
+class tool_rotate_building_t : public tool_t {
+private:
+	const char *tool_rotate_platform(koord3d);
+	const char *tool_rotate_building(koord3d);
+
+public:
+	tool_rotate_building_t() : tool_t(TOOL_ROTATE_BUILDING | GENERAL_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Rotate Building"); }
+	char const* work(player_t *, koord3d) OVERRIDE;
+	bool is_init_network_save() const OVERRIDE { return true; }
+};
+
 // builds roadsigns and signals
 class tool_build_roadsign_t : public two_click_tool_t {
 private:
@@ -410,11 +423,11 @@ private:
 		uint8 spacing; // place signals every n tiles
 		bool  remove_intermediate;
 		bool  replace_other;
-	} signal[MAX_PLAYER_COUNT];
-
-	static char toolstring[256];
-	// read the variables from the default_param
-	void read_default_param(player_t *player);
+	};
+	// default values for this tool per player
+	signal_info signal[MAX_PLAYER_COUNT];
+	// values that will be used to build
+	signal_info current;
 
 	const char* check_pos_intern(player_t *, koord3d);
 	bool calc_route( route_t &, player_t *, const koord3d& start, const koord3d &to );
@@ -437,13 +450,12 @@ public:
 	void get_values(player_t *player, uint8 &spacing, bool &remove, bool &replace );
 	bool is_init_network_save() const OVERRIDE { return true; }
 	void draw_after(scr_coord, bool dirty) const OVERRIDE;
-	char const* get_default_param(player_t*) const OVERRIDE;
+	void rdwr_custom_data(memory_rw_t*) OVERRIDE;
 	waytype_t get_waytype() const OVERRIDE;
 };
 
 class tool_build_depot_t : public tool_t {
 private:
-	static char toolstring[256];
 	const char *tool_depot_aux(player_t *player, koord3d pos, const building_desc_t *desc, waytype_t wegtype);
 public:
 	tool_build_depot_t() : tool_t(TOOL_BUILD_DEPOT | GENERAL_TOOL) {}
