@@ -61,6 +61,19 @@ protected:
 	// true on slope (make calc_height much faster)
 	uint8 use_calc_height:1;
 
+	/**
+	 * Thing is moving on this lane.
+	 * Possible values:
+	 * (Back)
+	 * 0 - sidewalk (going on the right side to w/sw/s)
+	 * 1 - road     (going on the right side to w/sw/s)
+	 * 2 - middle   (everything with waytype != road)
+	 * 3 - road     (going on the right side to se/e/../nw)
+	 * 4 - sidewalk (going on the right side to se/e/../nw)
+	 * (Front)
+	 */
+	uint8 disp_lane:3;
+
 	sint8 dx, dy;
 
 	// number of steps in this tile (255 per tile)
@@ -121,6 +134,8 @@ public:
 	sint16 get_hoff(const sint16 raster_width=1) const;
 	uint8 get_steps() const {return steps;}
 
+	uint8 get_disp_lane() const { return disp_lane; }
+
 	// to make smaller steps than the tile granularity, we have to calculate our offsets ourselves!
 	virtual void get_screen_offset( int &xoff, int &yoff, const sint16 raster_width ) const;
 
@@ -368,8 +383,6 @@ public:
 	*/
 	uint32 get_cargo_weight() const;
 
-	const char * get_cargo_name() const;
-
 	/**
 	* get the type of cargo this vehicle can transport
 	*/
@@ -420,7 +433,7 @@ public:
 	 * Unload freight to halt
 	 * @return sum of unloaded goods
 	 */
-	uint16 unload_cargo(halthandle_t halt);
+	uint16 unload_cargo(halthandle_t halt, bool all );
 
 	/**
 	 * Load freight from halt
@@ -486,6 +499,10 @@ protected:
 public:
 	virtual void enter_tile(grund_t*);
 
+	virtual void rotate90();
+
+	void calc_disp_lane();
+
 	virtual waytype_t get_waytype() const { return road_wt; }
 
 	road_vehicle_t(loadsave_t *file, bool first, bool last);
