@@ -72,6 +72,9 @@
 #include "message_option_t.h"
 #include "fabrik_info.h"
 #include "themeselector.h"
+#include "goods_frame_t.h"
+#include "loadfont_frame.h"
+#include "scenario_info.h"
 
 #include "../simversion.h"
 
@@ -166,6 +169,7 @@ static bool destroy_framed_win(simwin_t *win);
  */
 static int display_gadget_box(sint8 code,
 			      int const x, int const y,
+			      PIXVAL lighter, PIXVAL darker,
 			      bool const pushed)
 {
 
@@ -177,8 +181,8 @@ static int display_gadget_box(sint8 code,
 	}
 
 	if(pushed) {
-		mark_rect_dirty_wc(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT);
-		display_blend_wh_rgb(x+1, y+1, D_GADGET_WIDTH-2, D_TITLEBAR_HEIGHT-2, color_idx_to_rgb(COL_WHITE), 50);
+		// mark_rect_dirty_wc(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT);
+		display_fillbox_wh_rgb(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT, lighter, false);
 	}
 
 	// Do we have a gadget image?
@@ -208,8 +212,8 @@ static int display_gadget_box(sint8 code,
 	}
 
 	int side = x+REVERSE_GADGETS*D_GADGET_WIDTH-1;
-	display_blend_wh_rgb(side,   y+1, 1, D_TITLEBAR_HEIGHT-2, color_idx_to_rgb(COL_BLACK), 25);
-	display_blend_wh_rgb(side+1, y+1, 1, D_TITLEBAR_HEIGHT-2, color_idx_to_rgb(COL_WHITE), 25);
+	display_vline_wh_rgb(side+1, y+1, D_TITLEBAR_HEIGHT-2, lighter, false);
+	display_vline_wh_rgb(side,   y+1, D_TITLEBAR_HEIGHT-2, darker,  false);
 
 	// Hajo: return width of gadget
 	return D_GADGET_WIDTH;
@@ -221,6 +225,8 @@ static int display_gadget_box(sint8 code,
 static int display_gadget_boxes(
 	simwin_gadget_flags_t* flags,
 	int x, int y,
+	PIXVAL lighter,
+	PIXVAL darker,
 	uint16 gadget_state,
 	bool sticky_pushed,
 	bool goto_pushed
@@ -230,25 +236,25 @@ static int display_gadget_boxes(
 
 	// Only the close and sticky gadget can be pushed.
 	if(  flags->close  ) {
-		width += k*display_gadget_box( SKIN_GADGET_CLOSE, x + width, y, gadget_state & (1<<SKIN_GADGET_CLOSE) );
+		width += k*display_gadget_box( SKIN_GADGET_CLOSE, x + width, y, lighter, darker, gadget_state & (1<<SKIN_GADGET_CLOSE) );
 	}
 	if(  flags->size  ) {
-		width += k*display_gadget_box( SKIN_GADGET_MINIMIZE, x + width, y, gadget_state & (1<<SKIN_GADGET_MINIMIZE) );
+		width += k*display_gadget_box( SKIN_GADGET_MINIMIZE, x + width, y, lighter, darker, gadget_state & (1<<SKIN_GADGET_MINIMIZE) );
 	}
 	if(  flags->help  ) {
-		width += k*display_gadget_box( SKIN_GADGET_HELP, x + width, y, gadget_state & (1<<SKIN_GADGET_HELP) );
+		width += k*display_gadget_box( SKIN_GADGET_HELP, x + width, y, lighter, darker, gadget_state & (1<<SKIN_GADGET_HELP) );
 	}
 	if(  flags->prev  ) {
-		width += k*display_gadget_box( SKIN_BUTTON_PREVIOUS, x + width, y, gadget_state & (1<<SKIN_BUTTON_PREVIOUS) );
+		width += k*display_gadget_box( SKIN_BUTTON_PREVIOUS, x + width, y, lighter, darker, gadget_state & (1<<SKIN_BUTTON_PREVIOUS) );
 	}
 	if(  flags->next  ) {
-		width += k*display_gadget_box( SKIN_BUTTON_NEXT, x + width, y, gadget_state & (1<<SKIN_BUTTON_NEXT) );
+		width += k*display_gadget_box( SKIN_BUTTON_NEXT, x + width, y, lighter, darker, gadget_state & (1<<SKIN_BUTTON_NEXT) );
 	}
 	if(  flags->gotopos  ) {
-		width += k*display_gadget_box( SKIN_GADGET_GOTOPOS, x + width, y, goto_pushed  ||  (gadget_state & (1<<SKIN_GADGET_GOTOPOS)) );
+		width += k*display_gadget_box( SKIN_GADGET_GOTOPOS, x + width, y, lighter, darker, goto_pushed  ||  (gadget_state & (1<<SKIN_GADGET_GOTOPOS)) );
 	}
 	if(  flags->sticky  ) {
-		width += k*display_gadget_box( sticky_pushed ? SKIN_GADGET_PINNED : SKIN_GADGET_NOTPINNED, x + width, y, gadget_state & (1<<SKIN_GADGET_NOTPINNED) );
+		width += k*display_gadget_box( sticky_pushed ? SKIN_GADGET_PINNED : SKIN_GADGET_NOTPINNED, x + width, y, lighter, darker, gadget_state & (1<<SKIN_GADGET_NOTPINNED) );
 	}
 
 	return abs( width );
@@ -327,20 +333,21 @@ static void win_draw_window_title(const scr_coord pos, const scr_size size,
 		simwin_gadget_flags_t &flags )
 {
 	PUSH_CLIP(pos.x, pos.y, size.w, size.h);
+
+	PIXVAL lighter = display_blend_colors(title_color, color_idx_to_rgb(COL_WHITE), 25);
+	PIXVAL darker  = display_blend_colors(title_color, color_idx_to_rgb(COL_BLACK), 25);
+
 	display_fillbox_wh_clip_rgb(pos.x, pos.y, size.w, D_TITLEBAR_HEIGHT, title_color, false);
-	if ( title_color&TRANSPARENT_FLAGS) {
-		display_blend_wh_rgb( pos.x, pos.y, size.w, D_TITLEBAR_HEIGHT, color_idx_to_rgb(COL_BLACK), env_t::bottom_window_darkness);
-	}
 
-	display_blend_wh_rgb( pos.x + 1, pos.y,                         size.w - 2, 1, color_idx_to_rgb(COL_WHITE), 25 );
-	display_blend_wh_rgb( pos.x + 1, pos.y + D_TITLEBAR_HEIGHT - 1, size.w - 2, 1, color_idx_to_rgb(COL_BLACK), 25 );
+	display_fillbox_wh_rgb( pos.x + 1, pos.y,                         size.w - 2, 1, lighter, false );
+	display_fillbox_wh_rgb( pos.x + 1, pos.y + D_TITLEBAR_HEIGHT - 1, size.w - 2, 1, darker,  false );
 
-	display_blend_wh_rgb( pos.x,              pos.y, 1, D_TITLEBAR_HEIGHT, color_idx_to_rgb(COL_WHITE), 25 );
-	display_blend_wh_rgb( pos.x + size.w - 1, pos.y, 1, D_TITLEBAR_HEIGHT, color_idx_to_rgb(COL_BLACK), 25 );
+	display_vline_wh_rgb( pos.x,              pos.y, D_TITLEBAR_HEIGHT, lighter, false );
+	display_vline_wh_rgb( pos.x + size.w - 1, pos.y, D_TITLEBAR_HEIGHT, darker,  false );
 
 	// Draw the gadgets and then move left and draw text.
 	flags.gotopos = (welt_pos != koord3d::invalid);
-	int width = display_gadget_boxes( &flags, pos.x+(REVERSE_GADGETS?0:size.w-D_GADGET_WIDTH), pos.y, gadget_state, sticky, goto_pushed );
+	int width = display_gadget_boxes( &flags, pos.x+(REVERSE_GADGETS?0:size.w-D_GADGET_WIDTH), pos.y, lighter, darker, gadget_state, sticky, goto_pushed );
 	int titlewidth = display_proportional_clip_rgb( pos.x + (REVERSE_GADGETS?width+4:4), pos.y+(D_TITLEBAR_HEIGHT-LINEASCENT)/2, text, ALIGN_LEFT, text_color, false );
 	if(  flags.gotopos  ) {
 		display_proportional_clip_rgb( pos.x + (REVERSE_GADGETS?width+4:4)+titlewidth+8, pos.y+(D_TITLEBAR_HEIGHT-LINEASCENT)/2, welt_pos.get_2d().get_fullstr(), ALIGN_LEFT, text_color, false );
@@ -406,18 +413,6 @@ bool win_set_magic( gui_frame_t *gui, ptrdiff_t magic )
 }
 
 
-// returns the window on this positions
-gui_frame_t *win_get_oncoord( const scr_coord pt )
-{
-	for(  int i=wins.get_count()-1;  i>=0;  i--  ) {
-		if(  wins[i].gui->is_hit( pt.x-wins[i].pos.x, pt.y-wins[i].pos.y )  ) {
-			return wins[i].gui;
-		}
-	}
-	return NULL;
-}
-
-
 /**
  * Returns top window
  * @author prissi
@@ -516,6 +511,9 @@ void rdwr_all_win(loadsave_t *file)
 					case magic_messageframe:   w = new message_frame_t(); break;
 					case magic_message_options: w = new message_option_t(); break;
 					case magic_factory_info:   w = new fabrik_info_t(); break;
+					case magic_goodslist:      w = new goods_frame_t(); break;
+					case magic_font:           w = new loadfont_frame_t(); break;
+					case magic_scenario_info:  w = new scenario_info_t(); break;
 
 					default:
 						if(  id>=magic_finances_t  &&  id<magic_finances_t+MAX_PLAYER_COUNT  ) {
@@ -890,8 +888,8 @@ void display_win(int win)
 	FLAGGED_PIXVAL title_color = (comp->get_titlecolor()&0xFFFF);
 	FLAGGED_PIXVAL text_color = env_t::front_window_text_color;
 	if(  (unsigned)win!=wins.get_count()-1  ) {
-		// not top => maximum brightness
-		title_color = title_color | TRANSPARENT_FLAGS;
+		// not top => darker
+		title_color = display_blend_colors(title_color, color_idx_to_rgb(COL_BLACK), env_t::bottom_window_darkness);
 		text_color = env_t::bottom_window_text_color;
 	}
 	bool need_dragger = comp->get_resizemode() != gui_frame_t::no_resize;
@@ -1269,7 +1267,7 @@ bool check_pos_win(event_t *ev)
 	}
 
 	// cursor event only go to top window (but not if rolled up)
-	if(  ev->ev_class == EVENT_KEYBOARD  &&  !wins.empty()  ) {
+	if(  (ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  !wins.empty()  ) {
 		simwin_t &win  = wins.back();
 		if(  !win.rollup  )  {
 			inside_event_handling = win.gui;
@@ -1293,13 +1291,13 @@ bool check_pos_win(event_t *ev)
 	}
 
 	// swallow all other events in the infobar
-	if(  ev->ev_class != EVENT_KEYBOARD  &&  y > display_get_height()-16  ) {
+	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  y > display_get_height()-16  ) {
 		// swallow event
 		return true;
 	}
 
 	// swallow all other events in ticker (if there)
-	if(  ev->ev_class != EVENT_KEYBOARD  &&  show_ticker  &&  y > display_get_height()-32  ) {
+	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  show_ticker  &&  y > display_get_height()-32  ) {
 		if(  IS_LEFTCLICK(ev)  ) {
 			// goto infowin koordinate, if ticker is active
 			koord p = ticker::get_welt_pos();
@@ -1445,12 +1443,6 @@ bool check_pos_win(event_t *ev)
 }
 
 
-void win_get_event(event_t* const ev)
-{
-	display_get_event(ev);
-}
-
-
 void win_poll_event(event_t* const ev)
 {
 	display_poll_event(ev);
@@ -1465,7 +1457,7 @@ void win_poll_event(event_t* const ev)
 	}
 	// save and reload all windows (currently only used when a new theme is applied)
 	if(  ev->ev_class==EVENT_SYSTEM  &&  ev->ev_code==SYSTEM_RELOAD_WINDOWS  ) {
-		chdir( env_t::user_dir );
+		dr_chdir( env_t::user_dir );
 		loadsave_t dlg;
 		if(  dlg.wr_open( "dlgpos.xml", loadsave_t::xml_zipped, "temp", SERVER_SAVEGAME_VER_NR )  ) {
 			// save all
@@ -1592,18 +1584,22 @@ void win_display_flush(double konto)
 	char const *time = tick_to_string( wl->get_ticks(), true );
 
 	// statusbar background
+	KOORD_VAL const status_bar_height = max(LINESPACE + 2, 15);
+	KOORD_VAL const status_bar_y = disp_height - status_bar_height;
+	KOORD_VAL const status_bar_text_y = status_bar_y + (status_bar_height - LINESPACE) / 2;
+	KOORD_VAL const status_bar_icon_y = status_bar_y + (status_bar_height - 15) / 2;
 	display_set_clip_wh( 0, 0, disp_width, disp_height );
-	display_fillbox_wh_rgb(0, disp_height-16, disp_width, 1, SYSCOL_STATUSBAR_DIVIDER, false);
-	display_fillbox_wh_rgb(0, disp_height-15, disp_width, 15, SYSCOL_STATUSBAR_BACKGROUND, false);
+	display_fillbox_wh_rgb(0, status_bar_y - 1, disp_width, 1, SYSCOL_STATUSBAR_DIVIDER, false);
+	display_fillbox_wh_rgb(0, status_bar_y, disp_width, status_bar_height, SYSCOL_STATUSBAR_BACKGROUND, false);
 
-	bool tooltip_check = get_mouse_y()>disp_height-15;
+	bool tooltip_check = get_mouse_y() > status_bar_y;
 	if(  tooltip_check  ) {
 		tooltip_xpos = get_mouse_x();
-		tooltip_ypos = disp_height-15-10-TICKER_HEIGHT*show_ticker;
+		tooltip_ypos = status_bar_y-10-TICKER_HEIGHT*show_ticker;
 	}
 
 	// season color
-	display_color_img( skinverwaltung_t::seasons_icons->get_image_id(wl->get_season()), 2, disp_height-15, 0, false, true );
+	display_color_img( skinverwaltung_t::seasons_icons->get_image_id(wl->get_season()), 2, status_bar_icon_y, 0, false, true );
 	if(  tooltip_check  &&  tooltip_xpos<14  ) {
 		static char const* const seasons[] = { "q2", "q3", "q4", "q1" };
 		tooltip_text = translator::translate(seasons[wl->get_season()]);
@@ -1615,7 +1611,7 @@ void win_display_flush(double konto)
 	// shown if timeline game
 	if(  wl->use_timeline()  &&  skinverwaltung_t::timelinesymbol  ) {
 		right_border -= 14;
-		display_color_img( skinverwaltung_t::timelinesymbol->get_image_id(0), right_border, disp_height-15, 0, false, true );
+		display_color_img( skinverwaltung_t::timelinesymbol->get_image_id(0), right_border, status_bar_icon_y, 0, false, true );
 		if(  tooltip_check  &&  tooltip_xpos>=right_border  ) {
 			tooltip_text = translator::translate("timeline");
 			tooltip_check = false;
@@ -1625,7 +1621,7 @@ void win_display_flush(double konto)
 	// shown if connected
 	if(  env_t::networkmode  &&  skinverwaltung_t::networksymbol  ) {
 		right_border -= 14;
-		display_color_img( skinverwaltung_t::networksymbol->get_image_id(0), right_border, disp_height-15, 0, false, true );
+		display_color_img( skinverwaltung_t::networksymbol->get_image_id(0), right_border, status_bar_icon_y, 0, false, true );
 		if(  tooltip_check  &&  tooltip_xpos>=right_border  ) {
 			tooltip_text = translator::translate("Connected with server");
 			tooltip_check = false;
@@ -1635,7 +1631,7 @@ void win_display_flush(double konto)
 	// put pause icon
 	if(  wl->is_paused()  &&  skinverwaltung_t::pausesymbol  ) {
 		right_border -= 14;
-		display_color_img( skinverwaltung_t::pausesymbol->get_image_id(0), right_border, disp_height-15, 0, false, true );
+		display_color_img( skinverwaltung_t::pausesymbol->get_image_id(0), right_border, status_bar_icon_y, 0, false, true );
 		if(  tooltip_check  &&  tooltip_xpos>=right_border  ) {
 			tooltip_text = translator::translate("GAME PAUSED");
 			tooltip_check = false;
@@ -1645,7 +1641,7 @@ void win_display_flush(double konto)
 	// put fast forward icon
 	if(  wl->is_fast_forward()  &&  skinverwaltung_t::fastforwardsymbol  ) {
 		right_border -= 14;
-		display_color_img( skinverwaltung_t::fastforwardsymbol->get_image_id(0), right_border, disp_height-15, 0, false, true );
+		display_color_img( skinverwaltung_t::fastforwardsymbol->get_image_id(0), right_border, status_bar_icon_y, 0, false, true );
 		if(  tooltip_check  &&  tooltip_xpos>=right_border  ) {
 			tooltip_text = translator::translate("Fast forward");
 			tooltip_check = false;
@@ -1692,16 +1688,15 @@ void win_display_flush(double konto)
 		}
 	}
 #endif
-
-	scr_coord_val w_left = 20+display_proportional_rgb(20, disp_height-12, time, ALIGN_LEFT, SYSCOL_STATUSBAR_TEXT, true);
-	scr_coord_val w_right  = display_proportional_rgb(right_border-4, disp_height-12, info, ALIGN_RIGHT, SYSCOL_STATUSBAR_TEXT, true);
+	scr_coord_val w_left = 20+display_proportional_rgb(20, status_bar_text_y, time, ALIGN_LEFT, SYSCOL_STATUSBAR_TEXT, true);
+	scr_coord_val w_right  = display_proportional_rgb(right_border-4, status_bar_text_y, info, ALIGN_RIGHT, SYSCOL_STATUSBAR_TEXT, true);
 	scr_coord_val middle = (disp_width+((w_left+8)&0xFFF0)-((w_right+8)&0xFFF0))/2;
 
 	if(wl->get_active_player()) {
 		char buffer[256];
-		display_proportional_rgb( middle-5, disp_height-12, wl->get_active_player()->get_name(), ALIGN_RIGHT, PLAYER_FLAG|color_idx_to_rgb(wl->get_active_player()->get_player_color1()+0), true);
+		display_proportional_rgb( middle-5, status_bar_text_y, wl->get_active_player()->get_name(), ALIGN_RIGHT, PLAYER_FLAG|color_idx_to_rgb(wl->get_active_player()->get_player_color1()+0), true);
 		money_to_string(buffer, konto );
-		display_proportional_rgb( middle+5, disp_height-12, buffer, ALIGN_LEFT, konto >= 0.0?MONEY_PLUS:MONEY_MINUS, true);
+		display_proportional_rgb( middle+5, status_bar_text_y, buffer, ALIGN_LEFT, konto >= 0.0?MONEY_PLUS:MONEY_MINUS, true);
 	}
 }
 
