@@ -169,14 +169,12 @@ static char *recode(const char *src, bool translate_from_utf, bool translate_to_
 				}
 				else if(  translate_from_utf  ) {
 					// make latin from UTF8 (ignore overflows!)
-					size_t len = 0;
 					if(  !is_latin2  ) {
-						*dst++ = c = (uint8)utf8_to_utf16( (const utf8*)src, &len );
+						*dst++ = c = (uint8)utf8_decoder_t::decode((utf8 const *&)src);
 					}
 					else {
-						*dst++ = c = unicode_to_latin2( utf8_to_utf16( (const utf8*)src, &len ) );
+						*dst++ = c = unicode_to_latin2(utf8_decoder_t::decode((utf8 const *&)src));
 					}
-					src += len;
 				}
 			}
 			else if(c>=13) {
@@ -220,13 +218,13 @@ void translator::load_custom_list( int lang, vector_tpl<char *>&name_list, const
 		string local_file_name(env_t::user_dir);
 		local_file_name = local_file_name + "addons/" + pakset_path + "text/" + fileprefix + langs[lang].iso_base + ".txt";
 		DBG_DEBUG("translator::load_custom_list()", "try to read city name list from '%s'", local_file_name.c_str());
-		file = fopen(local_file_name.c_str(), "rb");
+		file = dr_fopen(local_file_name.c_str(), "rb");
 	}
 	// not found => try user location
 	if(  file==NULL  ) {
 		string local_file_name(env_t::user_dir);
 		local_file_name = local_file_name + fileprefix + langs[lang].iso_base + ".txt";
-		file = fopen(local_file_name.c_str(), "rb");
+		file = dr_fopen(local_file_name.c_str(), "rb");
 		DBG_DEBUG("translator::load_custom_list()", "try to read city name list from '%s'", local_file_name.c_str());
 	}
 	// not found => try pak location
@@ -234,14 +232,14 @@ void translator::load_custom_list( int lang, vector_tpl<char *>&name_list, const
 		string local_file_name(env_t::program_dir);
 		local_file_name = local_file_name + pakset_path + "text/" + fileprefix + langs[lang].iso_base + ".txt";
 		DBG_DEBUG("translator::load_custom_list()", "try to read city name list from '%s'", local_file_name.c_str());
-		file = fopen(local_file_name.c_str(), "rb");
+		file = dr_fopen(local_file_name.c_str(), "rb");
 	}
 	// not found => try global translations
 	if(  file==NULL  ) {
 		string local_file_name(env_t::program_dir);
 		local_file_name = local_file_name + "text/" + fileprefix + langs[lang].iso_base + ".txt";
 		DBG_DEBUG("translator::load_custom_list()", "try to read city name list from '%s'", local_file_name.c_str());
-		file = fopen(local_file_name.c_str(), "rb");
+		file = dr_fopen(local_file_name.c_str(), "rb");
 	}
 	fflush(NULL);
 
@@ -407,7 +405,7 @@ void translator::load_files_from_folder(const char *folder_name, const char *wha
 		lang_info* lang = get_lang_by_iso(iso.c_str());
 		if (lang != NULL) {
 			DBG_MESSAGE("translator::load_files_from_folder()", "loading %s translations from %s for language %s", what, fileName.c_str(), lang->iso_base);
-			if (FILE* const file = fopen(fileName.c_str(), "rb")) {
+			if (FILE* const file = dr_fopen(fileName.c_str(), "rb")) {
 				bool file_is_utf = is_unicode_file(file);
 				load_language_file_body(file, &lang->texts, true, file_is_utf, lang->is_latin2_based );
 				fclose(file);
@@ -425,7 +423,7 @@ void translator::load_files_from_folder(const char *folder_name, const char *wha
 
 bool translator::load(const string &path_to_pakset)
 {
-	chdir( env_t::program_dir );
+	dr_chdir( env_t::program_dir );
 	tstrncpy(pakset_path, path_to_pakset.c_str(), lengthof(pakset_path));
 
 	//initialize these values to 0(ie. nothing loaded)
@@ -442,7 +440,7 @@ bool translator::load(const string &path_to_pakset)
 		size_t pstart = fileName.rfind('/') + 1;
 		const string iso = fileName.substr(pstart, fileName.size() - pstart - 4);
 
-		if (FILE* const file = fopen(fileName.c_str(), "rb")) {
+		if (FILE* const file = dr_fopen(fileName.c_str(), "rb")) {
 			DBG_MESSAGE("translator::load()", "base file \"%s\" - iso: \"%s\"", fileName.c_str(), iso.c_str());
 			load_language_iso(iso);
 			load_language_file(file);
@@ -467,12 +465,12 @@ bool translator::load(const string &path_to_pakset)
 	load_files_from_folder(folderName.c_str(), "pak");
 
 	if(  env_t::default_settings.get_with_private_paks()  ) {
-		chdir( env_t::user_dir );
+		dr_chdir( env_t::user_dir );
 		// now read the pakset specific text
 		// there can be more than one file per language, provided it is name like iso_xyz.tab
 		const string folderName("addons/" + path_to_pakset + "text/");
 		load_files_from_folder(folderName.c_str(), "pak addons");
-		chdir( env_t::program_dir );
+		dr_chdir( env_t::program_dir );
 	}
 
 	//if NO languages were loaded then game cannot continue
@@ -481,7 +479,7 @@ bool translator::load(const string &path_to_pakset)
 	}
 
 	// now we try to read the compatibility stuff
-	if (FILE* const file = fopen((path_to_pakset + "compat.tab").c_str(), "rb")) {
+	if (FILE* const file = dr_fopen((path_to_pakset + "compat.tab").c_str(), "rb")) {
 		load_language_file_body(file, &compatibility, false, false, false );
 		DBG_MESSAGE("translator::load()", "pakset compatibility texts loaded.");
 		fclose(file);
@@ -492,13 +490,13 @@ bool translator::load(const string &path_to_pakset)
 
 	// also addon compatibility ...
 	if(  env_t::default_settings.get_with_private_paks()  ) {
-		chdir( env_t::user_dir );
-		if (FILE* const file = fopen(string("addons/"+path_to_pakset + "compat.tab").c_str(), "rb")) {
+		dr_chdir( env_t::user_dir );
+		if (FILE* const file = dr_fopen(string("addons/"+path_to_pakset + "compat.tab").c_str(), "rb")) {
 			load_language_file_body(file, &compatibility, false, false, false );
 			DBG_MESSAGE("translator::load()", "pakset addon compatibility texts loaded.");
 			fclose(file);
 		}
-		chdir( env_t::program_dir );
+		dr_chdir( env_t::program_dir );
 	}
 
 #if DEBUG>=4
