@@ -76,6 +76,8 @@ void viewport_t::change_world_position( koord new_ij, sint16 new_xoff, sint16 ne
 	new_ij.y += new_xoff/cached_img_size;
 	new_xoff %= cached_img_size;
 
+	new_ij = world->get_closest_coordinate(new_ij);
+
 	// truncate new_yoff, modify new_ij.y
 	int lines = 0;
 	if(new_yoff>0) {
@@ -279,22 +281,6 @@ koord3d viewport_t::get_new_cursor_position( const scr_coord &screen_pos, bool g
 }
 
 
-bool viewport_t::is_background_visible() const
-{
-
-	sint32 i,j;
-
-	if ( get_ground_on_screen_coordinate(scr_coord(0,0),i,j)  &&  \
-		get_ground_on_screen_coordinate(scr_coord(cached_disp_width-1,0),i,j)  &&  \
-		get_ground_on_screen_coordinate(scr_coord(0,cached_disp_height-1),i,j)  &&  \
-		get_ground_on_screen_coordinate(scr_coord(cached_disp_width-1,cached_disp_height-1),i,j)  ) {
-			return false;
-	}
-
-	return true;
-}
-
-
 void viewport_t::metrics_updated()
 {
 	cached_disp_width = display_get_width();
